##################################################
# RPC_Literal_TestDefinitions_services_server.py
#      Generated by ZSI.generate.wsdl2dispatch.ServiceModuleWriter
#
##################################################

from RPC_Literal_TestDefinitions_services import *
from ZSI.ServiceContainer import ServiceSOAPBinding

class WhiteMesaSoapRpcLitTestSvc(ServiceSOAPBinding):
    soapAction = {}
    root = {}
    _wsdl = """<?xml version=\"1.0\" ?>
<definitions name=\"RPC-Literal-TestDefinitions\" targetNamespace=\"http://whitemesa.net/wsdl/rpc-lit-test\" xmlns=\"http://schemas.xmlsoap.org/wsdl/\" xmlns:soap11=\"http://schemas.xmlsoap.org/wsdl/soap/\" xmlns:soap12=\"http://schemas.xmlsoap.org/wsdl/soap12/\" xmlns:tns=\"http://whitemesa.net/wsdl/rpc-lit-test\" xmlns:types=\"http://soapbuilders.org/rpc-lit-test/types\" xmlns:wsdl=\"http://schemas.xmlsoap.org/wsdl/\" xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\">
	<types>
		<schema targetNamespace=\"http://soapbuilders.org/rpc-lit-test/types\" xmlns=\"http://www.w3.org/2001/XMLSchema\">

            <element name=\"stringItem\" type=\"xsd:string\"/>
			<complexType name=\"ArrayOfstring\">
				<sequence>
					<element maxOccurs=\"unbounded\" minOccurs=\"0\" ref=\"types:stringItem\"/>
				</sequence>
			</complexType>

			<complexType name=\"ArrayOfint\">
				<sequence>
					<element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"integer\" type=\"xsd:int\"/>
				</sequence>
			</complexType>

            <element name=\"structItem\" type=\"types:SOAPStruct\"/>
			<complexType name=\"SOAPStruct\">
				<all>
					<element name=\"varString\" type=\"xsd:string\"/>
					<element name=\"varInt\" type=\"xsd:int\"/>
					<element name=\"varFloat\" type=\"xsd:float\"/>
				</all>
			</complexType>
			
			<complexType name=\"ArrayOfSOAPStruct\">
				<sequence>
					<element maxOccurs=\"unbounded\" minOccurs=\"0\" ref=\"types:structItem\"/>
				</sequence>
			</complexType>

			<complexType name=\"SOAPStructStruct\">
				<all>
					<element name=\"varString\" type=\"xsd:string\"/>
					<element name=\"varInt\" type=\"xsd:int\"/>
					<element name=\"varFloat\" type=\"xsd:float\"/>
					<element ref=\"types:structItem\"/>
				</all>
			</complexType>

			<complexType name=\"SOAPArrayStruct\">
				<all>
					<element name=\"varString\" type=\"xsd:string\"/>
					<element name=\"varInt\" type=\"xsd:int\"/>
					<element name=\"varFloat\" type=\"xsd:float\"/>
					<element name=\"varArray\" type=\"types:ArrayOfstring\"/>
				</all>
			</complexType>

		</schema>

	</types>

	<!-- echoStruct rpc operation -->
	<message name=\"echoStructRequest\">
		<part name=\"inputStruct\" type=\"types:SOAPStruct\"/>
	</message>
	<message name=\"echoStructResponse\">
		<part name=\"return\" type=\"types:SOAPStruct\"/>
	</message>

	<!-- echoStructArray rpc operation -->
	<message name=\"echoStructArrayRequest\">
		<part name=\"inputStructArray\" type=\"types:ArrayOfSOAPStruct\"/>
	</message>
	<message name=\"echoStructArrayResponse\">
		<part name=\"return\" type=\"types:ArrayOfSOAPStruct\"/>
	</message>

	<!-- echoStructAsSimpleTypes rpc operation -->
	<message name=\"echoStructAsSimpleTypesRequest\">
		<part name=\"inputStruct\" type=\"types:SOAPStruct\"/>
	</message>
	<message name=\"echoStructAsSimpleTypesResponse\">
		<part name=\"outputString\" type=\"xsd:string\"/>
		<part name=\"outputInteger\" type=\"xsd:int\"/>
		<part name=\"outputFloat\" type=\"xsd:float\"/>
	</message>

	<!-- echoSimpleTypesAsStruct rpc operation -->
	<message name=\"echoSimpleTypesAsStructRequest\">
		<part name=\"inputString\" type=\"xsd:string\"/>
		<part name=\"inputInteger\" type=\"xsd:int\"/>
		<part name=\"inputFloat\" type=\"xsd:float\"/>
	</message>
	<message name=\"echoSimpleTypesAsStructResponse\">
		<part name=\"return\" type=\"types:SOAPStruct\"/>
	</message>

	<!-- echoNestedStruct rpc operation -->
	<message name=\"echoNestedStructRequest\">
		<part name=\"inputStruct\" type=\"types:SOAPStructStruct\"/>
	</message>
	<message name=\"echoNestedStructResponse\">
		<part name=\"return\" type=\"types:SOAPStructStruct\"/>
	</message>

	<!-- echoNestedArray rpc operation -->
	<message name=\"echoNestedArrayRequest\">
		<part name=\"inputStruct\" type=\"types:SOAPArrayStruct\"/>
	</message>
	<message name=\"echoNestedArrayResponse\">
		<part name=\"return\" type=\"types:SOAPArrayStruct\"/>
	</message>

	<!-- echoStringArray rpc operation -->
	<message name=\"echoStringArrayRequest\">
		<part name=\"inputStringArray\" type=\"types:ArrayOfstring\"/>
	</message>
	<message name=\"echoStringArrayResponse\">
		<part name=\"return\" type=\"types:ArrayOfstring\"/>
	</message>

	<!-- echoIntegerArray rpc operation -->
	<message name=\"echoIntegerArrayRequest\">
		<part name=\"inputIntegerArray\" type=\"types:ArrayOfint\"/>
	</message>
	<message name=\"echoIntegerArrayResponse\">
		<part name=\"return\" type=\"types:ArrayOfint\"/>
	</message>

	<!-- echoBoolean rpc operation -->
	<message name=\"echoBooleanRequest\">
		<part name=\"inputBoolean\" type=\"xsd:boolean\"/>
	</message>
	<message name=\"echoBooleanResponse\">
		<part name=\"return\" type=\"xsd:boolean\"/>
	</message>

	<!-- echoString rpc operation -->
	<message name=\"echoStringRequest\">
		<part name=\"inputString\" type=\"xsd:string\"/>
	</message>
	<message name=\"echoStringResponse\">
		<part name=\"return\" type=\"xsd:string\"/>
	</message>


	<portType name=\"SoapTestPortTypeRpc\">

		<!-- echoStruct rpc operation -->
		<operation name=\"echoStruct\" parameterOrder=\"inputStruct\">
			<input message=\"tns:echoStructRequest\"/>
			<output message=\"tns:echoStructResponse\"/>
		</operation>

		<!-- echoStructArray rpc operation -->
		<operation name=\"echoStructArray\" parameterOrder=\"inputStructArray\">
			<input message=\"tns:echoStructArrayRequest\"/>
			<output message=\"tns:echoStructArrayResponse\"/>
		</operation>

		<!-- echoStructAsSimpleTypes rpc operation -->
		<operation name=\"echoStructAsSimpleTypes\" parameterOrder=\"inputStruct outputString outputInteger outputFloat\">
			<input message=\"tns:echoStructAsSimpleTypesRequest\"/>
			<output message=\"tns:echoStructAsSimpleTypesResponse\"/>
		</operation>

		<!-- echoSimpleTypesAsStruct rpc operation -->
		<operation name=\"echoSimpleTypesAsStruct\" parameterOrder=\"inputString inputInteger inputFloat\">
			<input message=\"tns:echoSimpleTypesAsStructRequest\"/>
			<output message=\"tns:echoSimpleTypesAsStructResponse\"/>
		</operation>

		<!-- echoNestedStruct rpc operation -->
		<operation name=\"echoNestedStruct\" parameterOrder=\"inputStruct\">
			<input message=\"tns:echoNestedStructRequest\"/>
			<output message=\"tns:echoNestedStructResponse\"/>
		</operation>

		<!-- echoNestedArray rpc operation -->
		<operation name=\"echoNestedArray\" parameterOrder=\"inputStruct\">
			<input message=\"tns:echoNestedArrayRequest\"/>
			<output message=\"tns:echoNestedArrayResponse\"/>
		</operation>

		<!-- echoStringArray rpc operation -->
		<operation name=\"echoStringArray\" parameterOrder=\"inputStringArray\">
			<input message=\"tns:echoStringArrayRequest\"/>
			<output message=\"tns:echoStringArrayResponse\"/>
		</operation>

		<!-- echoIntegerArray rpc operation -->
		<operation name=\"echoIntegerArray\" parameterOrder=\"inputIntegerArray\">
			<input message=\"tns:echoIntegerArrayRequest\"/>
			<output message=\"tns:echoIntegerArrayResponse\"/>
		</operation>

		<!-- echoBoolean rpc operation -->
		<operation name=\"echoBoolean\" parameterOrder=\"inputBoolean\">
			<input message=\"tns:echoBooleanRequest\"/>
			<output message=\"tns:echoBooleanResponse\"/>
		</operation>

		<!-- echoString rpc operation -->
		<operation name=\"echoString\" parameterOrder=\"inputString\">
			<input message=\"tns:echoStringRequest\"/>
			<output message=\"tns:echoStringResponse\"/>
		</operation>

	</portType>

	<binding name=\"Soap11TestRpcLitBinding\" type=\"tns:SoapTestPortTypeRpc\">
		<soap11:binding style=\"rpc\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>

		<!-- echoStruct rpc operation -->
		<operation name=\"echoStruct\">
			<soap11:operation soapAction=\"http://soapinterop.org/\"/>
			<input>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!--  echoStructArray rpc operation -->
		<operation name=\"echoStructArray\">
			<soap11:operation soapAction=\"http://soapinterop.org/\"/>
			<input>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!-- echoStructAsSimpleTypes rpc operation -->
		<operation name=\"echoStructAsSimpleTypes\">
			<soap11:operation soapAction=\"http://soapinterop.org/\"/>
			<input>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!-- echoSimpleTypesAsStruct rpc operation -->
		<operation name=\"echoSimpleTypesAsStruct\">
			<soap11:operation soapAction=\"http://soapinterop.org/\"/>
			<input>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!-- echoNestedStruct rpc operation -->
		<operation name=\"echoNestedStruct\">
			<soap11:operation soapAction=\"http://soapinterop.org/\"/>
			<input>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!-- echoNestedArray rpc operation -->
		<operation name=\"echoNestedArray\">
			<soap11:operation soapAction=\"http://soapinterop.org/\"/>
			<input>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!-- echoStringArray rpc operation -->
		<operation name=\"echoStringArray\">
			<soap11:operation soapAction=\"http://soapinterop.org/\"/>
			<input>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!-- echoIntegerArray rpc operation -->
		<operation name=\"echoIntegerArray\">
			<soap11:operation soapAction=\"http://soapinterop.org/\"/>
			<input>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!-- echoBoolean rpc operation -->
		<operation name=\"echoBoolean\">
			<soap11:operation soapAction=\"http://soapinterop.org/\"/>
			<input>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!-- echoString rpc operation -->
		<operation name=\"echoString\">
			<soap11:operation soapAction=\"http://soapinterop.org/\"/>
			<input>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap11:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

	</binding>

	<binding name=\"Soap12TestRpcLitBinding\" type=\"tns:SoapTestPortTypeRpc\">
		<soap12:binding style=\"rpc\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>

		<!-- echoStruct rpc operation -->
		<operation name=\"echoStruct\">
			<soap12:operation/>
			<input>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!--  echoStructArray rpc operation -->
		<operation name=\"echoStructArray\">
			<soap12:operation/>
			<input>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!-- echoStructAsSimpleTypes rpc operation -->
		<operation name=\"echoStructAsSimpleTypes\">
			<soap12:operation/>
			<input>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!-- echoSimpleTypesAsStruct rpc operation -->
		<operation name=\"echoSimpleTypesAsStruct\">
			<soap12:operation/>
			<input>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!-- echoNestedStruct rpc operation -->
		<operation name=\"echoNestedStruct\">
			<soap12:operation/>
			<input>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!-- echoNestedArray rpc operation -->
		<operation name=\"echoNestedArray\">
			<soap12:operation/>
			<input>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!-- echoStringArray rpc operation -->
		<operation name=\"echoStringArray\">
			<soap12:operation/>
			<input>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!-- echoIntegerArray rpc operation -->
		<operation name=\"echoIntegerArray\">
			<soap12:operation/>
			<input>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!-- echoBoolean rpc operation -->
		<operation name=\"echoBoolean\">
			<soap12:operation/>
			<input>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

		<!-- echoString rpc operation -->
		<operation name=\"echoString\">
			<soap12:operation/>
			<input>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</input>
			<output>
				<soap12:body namespace=\"http://soapbuilders.org/rpc-lit-test\" use=\"literal\"/>
			</output>
		</operation>

	</binding>

	<service name=\"WhiteMesaSoapRpcLitTestSvc\">

  		<port binding=\"tns:Soap12TestRpcLitBinding\" name=\"Soap12TestRpcLitPort\">
    			<soap12:address location=\"http://www.whitemesa.net/soap12/test-rpc-lit\"/>
  		</port>
  		<port binding=\"tns:Soap11TestRpcLitBinding\" name=\"Soap11TestRpcLitPort\">
    			<soap11:address location=\"http://www.whitemesa.net/test-rpc-lit\"/>
  		</port>

	</service>

</definitions>"""

    def __init__(self, post='/test-rpc-lit', **kw):
        ServiceSOAPBinding.__init__(self, post)

    def soap_echoStruct(self, ps):
        self.request = ps.Parse(echoStructRequest.typecode)
        return echoStructResponse()

    soapAction[''] = 'soap_echoStruct'
    root[(echoStructRequest.typecode.nspname,echoStructRequest.typecode.pname)] = 'soap_echoStruct'

    def soap_echoStructArray(self, ps):
        self.request = ps.Parse(echoStructArrayRequest.typecode)
        return echoStructArrayResponse()

    soapAction[''] = 'soap_echoStructArray'
    root[(echoStructArrayRequest.typecode.nspname,echoStructArrayRequest.typecode.pname)] = 'soap_echoStructArray'

    def soap_echoStructAsSimpleTypes(self, ps):
        self.request = ps.Parse(echoStructAsSimpleTypesRequest.typecode)
        return echoStructAsSimpleTypesResponse()

    soapAction[''] = 'soap_echoStructAsSimpleTypes'
    root[(echoStructAsSimpleTypesRequest.typecode.nspname,echoStructAsSimpleTypesRequest.typecode.pname)] = 'soap_echoStructAsSimpleTypes'

    def soap_echoSimpleTypesAsStruct(self, ps):
        self.request = ps.Parse(echoSimpleTypesAsStructRequest.typecode)
        return echoSimpleTypesAsStructResponse()

    soapAction[''] = 'soap_echoSimpleTypesAsStruct'
    root[(echoSimpleTypesAsStructRequest.typecode.nspname,echoSimpleTypesAsStructRequest.typecode.pname)] = 'soap_echoSimpleTypesAsStruct'

    def soap_echoNestedStruct(self, ps):
        self.request = ps.Parse(echoNestedStructRequest.typecode)
        return echoNestedStructResponse()

    soapAction[''] = 'soap_echoNestedStruct'
    root[(echoNestedStructRequest.typecode.nspname,echoNestedStructRequest.typecode.pname)] = 'soap_echoNestedStruct'

    def soap_echoNestedArray(self, ps):
        self.request = ps.Parse(echoNestedArrayRequest.typecode)
        return echoNestedArrayResponse()

    soapAction[''] = 'soap_echoNestedArray'
    root[(echoNestedArrayRequest.typecode.nspname,echoNestedArrayRequest.typecode.pname)] = 'soap_echoNestedArray'

    def soap_echoStringArray(self, ps):
        self.request = ps.Parse(echoStringArrayRequest.typecode)
        return echoStringArrayResponse()

    soapAction[''] = 'soap_echoStringArray'
    root[(echoStringArrayRequest.typecode.nspname,echoStringArrayRequest.typecode.pname)] = 'soap_echoStringArray'

    def soap_echoIntegerArray(self, ps):
        self.request = ps.Parse(echoIntegerArrayRequest.typecode)
        return echoIntegerArrayResponse()

    soapAction[''] = 'soap_echoIntegerArray'
    root[(echoIntegerArrayRequest.typecode.nspname,echoIntegerArrayRequest.typecode.pname)] = 'soap_echoIntegerArray'

    def soap_echoBoolean(self, ps):
        self.request = ps.Parse(echoBooleanRequest.typecode)
        return echoBooleanResponse()

    soapAction[''] = 'soap_echoBoolean'
    root[(echoBooleanRequest.typecode.nspname,echoBooleanRequest.typecode.pname)] = 'soap_echoBoolean'

    def soap_echoString(self, ps):
        self.request = ps.Parse(echoStringRequest.typecode)
        return echoStringResponse()

    soapAction[''] = 'soap_echoString'
    root[(echoStringRequest.typecode.nspname,echoStringRequest.typecode.pname)] = 'soap_echoString'

    def soap_echoStruct(self, ps):
        self.request = ps.Parse(echoStructRequest.typecode)
        return echoStructResponse()

    soapAction['http://soapinterop.org/'] = 'soap_echoStruct'
    root[(echoStructRequest.typecode.nspname,echoStructRequest.typecode.pname)] = 'soap_echoStruct'

    def soap_echoStructArray(self, ps):
        self.request = ps.Parse(echoStructArrayRequest.typecode)
        return echoStructArrayResponse()

    soapAction['http://soapinterop.org/'] = 'soap_echoStructArray'
    root[(echoStructArrayRequest.typecode.nspname,echoStructArrayRequest.typecode.pname)] = 'soap_echoStructArray'

    def soap_echoStructAsSimpleTypes(self, ps):
        self.request = ps.Parse(echoStructAsSimpleTypesRequest.typecode)
        return echoStructAsSimpleTypesResponse()

    soapAction['http://soapinterop.org/'] = 'soap_echoStructAsSimpleTypes'
    root[(echoStructAsSimpleTypesRequest.typecode.nspname,echoStructAsSimpleTypesRequest.typecode.pname)] = 'soap_echoStructAsSimpleTypes'

    def soap_echoSimpleTypesAsStruct(self, ps):
        self.request = ps.Parse(echoSimpleTypesAsStructRequest.typecode)
        return echoSimpleTypesAsStructResponse()

    soapAction['http://soapinterop.org/'] = 'soap_echoSimpleTypesAsStruct'
    root[(echoSimpleTypesAsStructRequest.typecode.nspname,echoSimpleTypesAsStructRequest.typecode.pname)] = 'soap_echoSimpleTypesAsStruct'

    def soap_echoNestedStruct(self, ps):
        self.request = ps.Parse(echoNestedStructRequest.typecode)
        return echoNestedStructResponse()

    soapAction['http://soapinterop.org/'] = 'soap_echoNestedStruct'
    root[(echoNestedStructRequest.typecode.nspname,echoNestedStructRequest.typecode.pname)] = 'soap_echoNestedStruct'

    def soap_echoNestedArray(self, ps):
        self.request = ps.Parse(echoNestedArrayRequest.typecode)
        return echoNestedArrayResponse()

    soapAction['http://soapinterop.org/'] = 'soap_echoNestedArray'
    root[(echoNestedArrayRequest.typecode.nspname,echoNestedArrayRequest.typecode.pname)] = 'soap_echoNestedArray'

    def soap_echoStringArray(self, ps):
        self.request = ps.Parse(echoStringArrayRequest.typecode)
        return echoStringArrayResponse()

    soapAction['http://soapinterop.org/'] = 'soap_echoStringArray'
    root[(echoStringArrayRequest.typecode.nspname,echoStringArrayRequest.typecode.pname)] = 'soap_echoStringArray'

    def soap_echoIntegerArray(self, ps):
        self.request = ps.Parse(echoIntegerArrayRequest.typecode)
        return echoIntegerArrayResponse()

    soapAction['http://soapinterop.org/'] = 'soap_echoIntegerArray'
    root[(echoIntegerArrayRequest.typecode.nspname,echoIntegerArrayRequest.typecode.pname)] = 'soap_echoIntegerArray'

    def soap_echoBoolean(self, ps):
        self.request = ps.Parse(echoBooleanRequest.typecode)
        return echoBooleanResponse()

    soapAction['http://soapinterop.org/'] = 'soap_echoBoolean'
    root[(echoBooleanRequest.typecode.nspname,echoBooleanRequest.typecode.pname)] = 'soap_echoBoolean'

    def soap_echoString(self, ps):
        self.request = ps.Parse(echoStringRequest.typecode)
        return echoStringResponse()

    soapAction['http://soapinterop.org/'] = 'soap_echoString'
    root[(echoStringRequest.typecode.nspname,echoStringRequest.typecode.pname)] = 'soap_echoString'




############################################################################
# Monte M. Goode, LBNL
# See LBNLCopyright for copyright notice!
###########################################################################

# main generator engine for new generation generator

# $Id: wsdl2python.py 1138 2006-02-27 18:08:35 -0500 (Mon, 27 Feb 2006) boverhof $

import os
from ZSI import _get_idstr
from ZSI.wstools.Utility import Base
from ZSI.wstools import WSDLTools
from ZSI.wstools.WSDLTools import SoapAddressBinding,\
    SoapBodyBinding, SoapBinding,MimeContentBinding,\
    HttpUrlEncodedBinding
from ZSI.wstools.XMLSchema import SchemaReader, ElementDeclaration, SchemaError
from ZSI.typeinterpreter import BaseTypeInterpreter
from ZSI.generate import WsdlGeneratorError, Wsdl2PythonError
from containers import *
from ZSI.generate import utility
from ZSI.generate.utility import NamespaceAliasDict as NAD
from ZSI.generate.utility import GetModuleBaseNameFromWSDL

"""
classes:
    WriteServiceModule 
    -- composes/writes out client stubs and types module.

    ServiceDescription
    -- represents a single WSDL service.

    MessageWriter
    -- represents a single WSDL Message and associated bindings
    of the port/binding.

    SchemaDescription 
    -- generates classes for defs and decs in the schema instance.

    TypeWriter
    -- represents a type definition.

    ElementWriter
    -- represents a element declaration.

"""

class WriteServiceModule(Base):
    """top level driver class invoked by wsd2py
    class variables:
        client_module_suffix -- suffix of client module.
        types_module_suffix -- suffix of types module.
    """
    client_module_suffix = '_services'
    messages_module_suffix = '_messages'
    types_module_suffix = '_services_types'
 
    def __init__(self, wsdl, addressing=False, notification=False,
                 do_extended=False, extPyClasses=None, configParser = None):
        Base.__init__(self)
        self._wsdl = wsdl
        self._addressing = addressing
        self._notification = notification
        self._configParser = configParser
        self.usedNamespaces = None
        self.services = []
        self.client_module_path = None
        self.types_module_name = None
        self.types_module_path = None
        self.messages_module_path = None # used in extended generation
        self.do_extended = do_extended
        self.extPyClasses = extPyClasses
       
    def getClientModuleName(self):
        """client module name.
        """
        name = GetModuleBaseNameFromWSDL(self._wsdl)
        if not name:
            raise WsdlGeneratorError, 'could not determine a service name'
        
        if self.client_module_suffix is None:
            return name

        return '%s%s' %(name, self.client_module_suffix)

    def getMessagesModuleName(self):
        name = GetModuleBaseNameFromWSDL(self._wsdl)
        if not name:
            raise WsdlGeneratorError, 'could not determine a service name'
        
        if self.messages_module_suffix is None:
            return name

        if len(self.messages_module_suffix) == 0:
            return self.getClientModuleName()

        return '%s%s' %(name, self.messages_module_suffix)

    def setTypesModuleName(self, name):
        self.types_module_name = name

    def getTypesModuleName(self):
        """types module name.
        """
        if self.types_module_name is not None:
            return self.types_module_name

        name = GetModuleBaseNameFromWSDL(self._wsdl)
        if not name:
            raise WsdlGeneratorError, 'could not determine a service name'
        
        if self.types_module_suffix is None:
            return name

        return '%s%s' %(name, self.types_module_suffix)

    def setClientModulePath(self, path):
        """setup module path to where client module before calling fromWsdl.
        module path to types module eg. MyApp.client
        """
        self.client_module_path = path

    def getTypesModulePath(self):
        """module path to types module eg. MyApp.types
        """
        return self.types_module_path 

    def getMessagesModulePath(self):
        '''module path to messages module
           same as types path
        '''
        return self.messages_module_path 

    def setTypesModulePath(self, path):
        """setup module path to where service module before calling fromWsdl.
        module path to types module eg. MyApp.types
        """
        self.types_module_path = path

    def setMessagesModulePath(self, path):
        """setup module path to where message module before calling fromWsdl.
        module path to types module eg. MyApp.types
        """
        self.messages_module_path = path

    def gatherNamespaces(self):
        '''This method must execute once..  Grab all schemas
        representing each targetNamespace.
        '''
        if self.usedNamespaces is not None:
            return

        self.logger.debug('gatherNamespaces')
        self.usedNamespaces = {}
            
        # Add all schemas defined in wsdl
        # to used namespace and to the Alias dict
        for schema in self._wsdl.types.values():
            tns = schema.getTargetNamespace()
            self.logger.debug('Register schema(%s) -- TNS(%s)'\
                %(_get_idstr(schema), tns),)
            if self.usedNamespaces.has_key(tns) is False:
                self.usedNamespaces[tns] = []
            self.usedNamespaces[tns].append(schema)
            NAD.add(tns)
            
        # Add all xsd:import schema instances
        # to used namespace and to the Alias dict
        for k,v in SchemaReader.namespaceToSchema.items():
            self.logger.debug('Register schema(%s) -- TNS(%s)'\
                %(_get_idstr(v), k),)
            if self.usedNamespaces.has_key(k) is False:
                self.usedNamespaces[k] = []
            self.usedNamespaces[k].append(v)
            NAD.add(k)
            
    def writeClient(self, fd, sdClass=None, msg_fd=None, **kw):
        """write out client module to file descriptor.
        Parameters and Keywords arguments:
            fd -- file descriptor
            msg_fd -- optional messsages module file descriptor
            sdClass -- service description class name
            imports -- list of imports
            readerclass -- class name of ParsedSoap reader
            writerclass -- class name of SoapWriter writer
        """
        sdClass = sdClass or ServiceDescription
        assert issubclass(sdClass, ServiceDescription), \
            'parameter sdClass must subclass ServiceDescription'

        header = '%s \n# %s.py \n# generated by %s\n%s\n\n'\
                  %('#'*50, self.getClientModuleName(), self.__module__, '#'*50)
        fd.write(header)

        if msg_fd is not None:
            # TODO: Why is this not getMessagesModuleName?
            msg_filename = str(self.getClientModuleName()).replace("client", "messages")
            if self.getMessagesModulePath() is not None:
                msg_filename = os.path.join(self.getMessagesModulePath(), msg_filename)
            messages_header = header.replace("client", "messages")
            msg_fd.write(messages_header)

        self.services = []
        for service in self._wsdl.services:
            sd = sdClass(self._addressing, do_extended=self.do_extended, wsdl=self._wsdl)
            if len(self._wsdl.types) > 0:
                sd.setTypesModuleName(self.getTypesModuleName(), self.getTypesModulePath())
                sd.setMessagesModuleName(self.getMessagesModuleName(), self.getMessagesModulePath())

            self.gatherNamespaces()
            sd.fromWsdl(service, **kw)
            sd.write(fd,msg_fd)
            self.services.append(sd)

    def writeTypes(self, fd):
        """write out types module to file descriptor.
        """
        header = '%s \n# %s.py \n# generated by %s\n%s\n\n'\
                  %('#'*50, self.getTypesModuleName(), self.__module__, '#'*50)
        fd.write(header)
        print >>fd, TypesHeaderContainer()
        self.gatherNamespaces()
        for l in self.usedNamespaces.values():
            sd = SchemaDescription(do_extended=self.do_extended, extPyClasses=self.extPyClasses)
            for schema in l:
                sd.fromSchema(schema)
            sd.write(fd)

            
class ServiceDescription(Base):
    """client interface - locator, port, etc classes"""
    separate_messages = False

    def __init__(self, addressing=False, do_extended=False, wsdl=None):
        Base.__init__(self)
        self.typesModuleName = None
        self.messagesModuleName = None
        self.wsAddressing = addressing
        self.imports   = ServiceHeaderContainer()
        self.messagesImports   = ServiceHeaderContainer()
        self.locator   = ServiceLocatorContainer()
        self.methods   = []
        self.messages  = []
        self.do_extended=do_extended
        self._wsdl = wsdl # None unless do_extended == True

    def setTypesModuleName(self, name, modulePath=None):
        """The types module to be imported.
        Parameters
        name -- name of types module
        modulePath -- optional path where module is located.
        """
        self.typesModuleName = '%s' %name
        if modulePath is not None:
            self.typesModuleName = '%s.%s' %(modulePath,name)

    def setMessagesModuleName(self, name, modulePath=None):
        '''The types module to be imported.
        Parameters
        name -- name of types module
        modulePath -- optional path where module is located.
        '''
        self.messagesModuleName = '%s' %name
        if modulePath is not None:
            self.messagesModuleName = '%s.%s' %(modulePath,name)

    def fromWsdl(self, service, **kw):
        self.imports.setTypesModuleName(self.typesModuleName)
        if self.separate_messages:
            self.messagesImports.setMessagesModuleName(self.messagesModuleName)
        self.imports.appendImport(kw.get('imports', []))

        self.locator.setUp(service)

        for port in service.ports:
            sop_container = ServiceOperationsClassContainer(useWSA=self.wsAddressing, do_extended=self.do_extended, wsdl=self._wsdl)
            try:
                sop_container.setUp(port)
            except Wsdl2PythonError, ex:
                self.logger.warning('Skipping port(%s)' %port.name)
                if len(ex.args): 
                    self.logger.warning(ex.args[0])
            else:
                sop_container.setReaderClass(kw.get('readerclass'))
                sop_container.setWriterClass(kw.get('writerclass'))
                for soc in sop_container.operations:
                    if soc.hasInput() is True:
                        mw = MessageWriter(do_extended=self.do_extended)
                        mw.setUp(soc, port, input=True)
                        self.messages.append(mw)

                        if soc.hasOutput() is True:
                            mw = MessageWriter(do_extended=self.do_extended)
                            mw.setUp(soc, port, input=False)
                            self.messages.append(mw)

                self.methods.append(sop_container)

 
    def write(self, fd, msg_fd=None):
        """write out module to file descriptor.
        fd -- file descriptor to write out service description.
        msg_fd -- optional file descriptor for messages module.
        """
        if msg_fd != None:
            print >>fd, self.messagesImports
            print >>msg_fd, self.imports
        else:
            print >>fd, self.imports
        print >>fd, self.locator
        for m in self.methods:
            print >>fd, m

        if msg_fd != None:
            for m in self.messages:
                print >>msg_fd, m
        else:
            for m in self.messages:
                print >>fd, m


class MessageWriter(Base):
    def __init__(self, do_extended=False):
        """Representation of a WSDL Message and associated WSDL Binding.
        operation --
        boperation --
        input --
        rpc --
        literal --
        simple --
        """
        Base.__init__(self)
        self.content = None
        self.do_extended = do_extended
       
    def __str__(self):
        if not self.content:
            raise Wsdl2PythonError, 'Must call setUp.'
        return self.content.getvalue()
        
    def setUp(self, soc, port, input=False):
        assert isinstance(soc, ServiceOperationContainer),\
            'expecting a ServiceOperationContainer instance'
        assert isinstance(port, WSDLTools.Port),\
            'expecting a WSDL.Port instance'

        rpc,literal = soc.isRPC(), soc.isLiteral(input)
        kw,klass = {}, None
        
        if rpc and literal:
            klass = ServiceRPCLiteralMessageContainer
        elif not rpc and literal:
            kw['do_extended'] = self.do_extended
            klass = ServiceDocumentLiteralMessageContainer
        elif rpc and not literal:
            klass = ServiceRPCEncodedMessageContainer
        else:
            raise WsdlGeneratorError, 'doc/enc not supported.'
                                
        self.content = klass(**kw)
        self.content.setUp(port, soc, input)


class SchemaDescription(Base):
    """generates classes for defs and decs in the schema instance.
    """
    def __init__(self, do_extended=False, extPyClasses=None):
        Base.__init__(self)
        self.classHead = NamespaceClassHeaderContainer()
        self.classFoot = NamespaceClassFooterContainer()
        self.items = []
        self.__types = []
        self.__elements = []
        self.targetNamespace = None
        self.do_extended=do_extended
        self.extPyClasses = extPyClasses

    def fromSchema(self, schema):
        ''' Can be called multiple times, but will not redefine a
        previously defined type definition or element declaration.
        '''  
        ns = schema.getTargetNamespace()
        assert self.targetNamespace is None or self.targetNamespace == ns,\
            'SchemaDescription instance represents %s, not %s'\
            %(self.targetNamespace, ns)

        if self.targetNamespace is None:
            self.targetNamespace = ns
 
        self.classHead.ns = self.classFoot.ns = ns
        for item in [t for t in schema.types if t.getAttributeName() not in self.__types]:
            self.__types.append(item.getAttributeName())
            self.items.append(TypeWriter(do_extended=self.do_extended, extPyClasses=self.extPyClasses))
            self.items[-1].fromSchemaItem(item)

        for item in [e for e in schema.elements if e.getAttributeName() not in self.__elements]:
            self.__elements.append(item.getAttributeName())
            self.items.append(ElementWriter(do_extended=self.do_extended))
            self.items[-1].fromSchemaItem(item)

    def getTypes(self):
        return self.__types

    def getElements(self):
        return self.__elements

    def write(self, fd):
        """write out to file descriptor.
        """
        print >>fd, self.classHead
        for t in self.items:
            print >>fd, t
        print >>fd, self.classFoot

class SchemaItemWriter(Base):
    """contains/generates a single declaration"""
    def __init__(self, do_extended=False, extPyClasses=None):
        Base.__init__(self)
        self.content = None
        self.do_extended=do_extended
        self.extPyClasses=extPyClasses
        
    def __str__(self):
        '''this appears to set up whatever is in self.content.localElements,
        local elements simpleType|complexType.
        '''
        assert self.content is not None, 'Must call fromSchemaItem to setup.'
        return str(self.content)

    def fromSchemaItem(self, item):
        raise NotImplementedError, ''


class ElementWriter(SchemaItemWriter):
    """contains/generates a single declaration"""

    def fromSchemaItem(self, item):
        """set up global elements.
        """
        if item.isElement() is False or item.isLocal() is True:
            raise TypeError, 'expecting global element declaration: %s' %item.getItemTrace()

        local = False
        qName = item.getAttribute('type')
        if not qName:
            etp = item.content
            local = True
        else:
            etp = item.getTypeDefinition('type')
            
        if etp is None:
            if local is True: 
                self.content = ElementLocalComplexTypeContainer(do_extended=self.do_extended)
            else: 
                self.content = ElementSimpleTypeContainer()
        elif etp.isLocal() is False:
            self.content = ElementGlobalDefContainer()
        elif etp.isSimple() is True: 
            self.content = ElementLocalSimpleTypeContainer()
        elif etp.isComplex():
            self.content = ElementLocalComplexTypeContainer(do_extended=self.do_extended)
        else:
            raise Wsdl2PythonError, "Unknown element declaration: %s" %item.getItemTrace()

        self.content.setUp(item)


class TypeWriter(SchemaItemWriter):
    """contains/generates a single definition"""
        
    def fromSchemaItem(self, item):
        if item.isDefinition() is False or item.isLocal() is True:
            raise TypeError, \
                'expecting global type definition not: %s' %item.getItemTrace()

        self.content = None
        if item.isSimple():
            if item.content.isRestriction():
                self.content = RestrictionContainer()
            elif item.content.isUnion():
                self.content = UnionContainer()
            elif item.content.isList():
                self.content = ListContainer()
            else:
                raise Wsdl2PythonError,\
                    'unknown simple type definition: %s' %item.getItemTrace()
                    
            self.content.setUp(item)
            return
        
        if item.isComplex():
            kw = {}
            if item.content is None or item.content.isModelGroup():
                self.content = \
                    ComplexTypeContainer(\
                        do_extended=self.do_extended, 
                        extPyClasses=self.extPyClasses
                        )
                kw['empty'] = item.content is None
            elif item.content.isSimple():
                    self.content = ComplexTypeSimpleContentContainer()
            elif item.content.isComplex():
                    self.content = \
                        ComplexTypeComplexContentContainer(\
                            do_extended=self.do_extended
                            )
            else:
                raise Wsdl2PythonError,\
                    'unknown complex type definition: %s' %item.getItemTrace()
                    
            self.content.setUp(item, **kw)
            return

        raise TypeError,\
            'expecting SimpleType or ComplexType: %s' %item.getItemTrace()

        




#!/usr/bin/env python

############################################################################
# David W. Robertson, LBNL
# See LBNLCopyright for copyright notice!
###########################################################################
import sys, unittest
from ServiceTest import ServiceTestCase, ServiceTestSuite

"""
Unittest for contacting the ZipCodeResolver Web service.

WSDL: http://webservices.eraserver.net/zipcoderesolver/zipcoderesolver.asmx?WSDL

"""

CONFIG_FILE = 'config.txt'
CONFIG_SECTION = 'WSDL'
SERVICE_NAME = 'ZipCodeResolver'
PORT_NAME = 'ZipCodeResolverSoap'


class ZipCodeResolverTest(ServiceTestCase):
    """Test case for ZipCodeResolver Web service
    """
    name = "test_ZipCodeResolver"
    def setUp(self):
        self._portName = PORT_NAME
        ServiceTestCase.setSection(self,self.name)
        ServiceTestCase.setUp(self)
    
    def test_CorrectedAddressHtml(self):
        operationName = 'CorrectedAddressHtml'
        request = self.getInputMessageInstance(operationName)
        request._address = '636 Colusa Avenue'
        request._city = 'Berkeley'
        request._state = 'California'
        response = self.RPC(operationName, request)

    def test_CorrectedAddressXml(self):
        operationName = 'CorrectedAddressXml'
        request = self.getInputMessageInstance(operationName)
        request._address = '636 Colusa Avenue'
        request._city = 'Berkeley'
        request._state = 'California'
        response = self.RPC(operationName, request)
         
    def test_FullZipCode(self):
        operationName= 'FullZipCode'
        request = self.getInputMessageInstance(operationName)
        request._address = '636 Colusa Avenue'
        request._city = 'Berkeley'
        request._state = 'California'
        response = self.RPC(operationName, request)
    
    def test_ShortZipCode(self):
        operationName = 'ShortZipCode'
        request = self.getInputMessageInstance(operationName)
        request._address = '636 Colusa Avenue'
        request._city = 'Berkeley'
        request._state = 'California'
        response = self.RPC(operationName, request)
    
    def test_VersionInfo(self):
        operationName = 'VersionInfo'
        request = self.getInputMessageInstance(operationName)
        response = self.RPC(operationName, request)

    def _getPort(self, locator, netloc=None):
        """Returns a rpc proxy port instance.
           **Only expecting 1 service/WSDL, and 1 port/service.

           locator -- Locator instance
        """
        if len(self._wsm.services) != 1:
            raise TestException, 'only supporting WSDL with one service information item'
        methodNames = self._wsm.services[0].locator.getPortMethods()
        if len(methodNames) == 0:
            raise TestException, 'No port defined for service.'
        #elif len(methodNames) > 1:
        #    raise TestException, 'Not handling multiple ports.'
        callMethod = getattr(locator, methodNames[0])
        return callMethod(**self._getPortOptions(methodNames[0], locator, netloc))

def makeTestSuite():
    suite = ServiceTestSuite()
    suite.addTest(unittest.makeSuite(ZipCodeResolverTest, 'test_'))
    return suite


if __name__ == "__main__" :
    unittest.TestProgram(defaultTest="makeTestSuite")



#! /usr/bin/env python
# $Header$
import sys
from distutils.command.build import build as _build
from distutils.command.build_py import build_py as _build_py
try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

_url = "http://pywebsvcs.sf.net/"

import ConfigParser
cf = ConfigParser.ConfigParser()
cf.read('setup.cfg')
major = cf.getint('version', 'major')
minor = cf.getint('version', 'minor')
patchlevel = cf.getint('version', 'patchlevel')
candidate = cf.getint('version', 'candidate')

_version = "%d.%d" % ( major, minor )
if patchlevel:
    _version += '.%d' % patchlevel
if candidate:
    _version += '_rc%d' % candidate

try:
    open('ZSI/version.py', 'r').close()
except:
    print 'ZSI/version.py not found; run "make"'
    sys.exit(1)

_twisted_packages = ['ZSI.twisted']
_twisted_options = [('twisted', None, 'build twisted packages')]

class build_py(_build_py):
    user_options = _build_py.user_options[:]
    user_options += _twisted_options
    boolean_options = _build.boolean_options[:]
    boolean_options.append(_twisted_options[0][0])

    def initialize_options(self):
        _build_py.initialize_options(self)
        self.twisted = False

    def run(self):
        if self.twisted:
            self.distribution.packages += _twisted_packages
        return _build_py.run(self)


class build(_build):
    user_options = _build.user_options[:]
    user_options += _twisted_options
    boolean_options = _build.boolean_options[:]
    boolean_options.append(_twisted_options[0][0])

    def initialize_options(self):
        _build.initialize_options(self)
        self.twisted = False

    def run(self):
        if self.twisted:
            self.distribution.packages += _twisted_packages
        return _build.run(self)


setup(
    name="ZSI",
    version=_version,
    license="Python",
    packages=[ "ZSI", "ZSI.generate", "ZSI.wstools"],
    scripts=["scripts/wsdl2py.py", "scripts/wsdl2dispatch.py"],
    description="Zolera SOAP Infrastructure",
    author="Rich Salz, et al",
    author_email="rsalz@datapower.com",
    maintainer="Rich Salz, et al",
    maintainer_email="pywebsvcs-talk@lists.sf.net",
    url=_url,
    long_description='For additional information, please see ' + _url,
    cmdclass={'build':build, 'build_py':build_py},
)



#!/usr/bin/env python
############################################################################
# Joshua R. Boverhof, LBNL
# See LBNLCopyright for copyright notice!
###########################################################################
import sys, unittest
from ServiceTest import ServiceTestCase, ServiceTestSuite
import ZSI
from ZSI import FaultException
"""
Unittest for contacting the OPC XML-DA Service.

WSDL:  http://tswinc.us/XMLDADemo/ts_sim/OpcDaGateway.asmx?WSDL
"""

CONFIG_FILE = 'config.txt'
SERVICE_NAME = 'OpcXmlDaSrv'
PORT_NAME = 'OpcXmlDaSrvSoapSOAP'


class OPCServiceTest(ServiceTestCase):
    """Test case for OPCService Web service
    
    def GetProperties(self, request):
    def Subscribe(self, request):
    def SubscriptionPolledRefresh(self, request):
    def SubscriptionCancel(self, request):
    def GetStatus(self, request):
    def Browse(self, request):
    def Read(self, request):
    def Write(self, request):
    """
    name = "test_OpcDaGateway"

    def setUp(self):
        ServiceTestCase.setSection(self,self.name)
        ServiceTestCase.setUp(self)
        
    def hangs_test_rpc_GetProperties(self):
        """sending an empty GetProperties request, 
        receiving empty response.
        
        <GetPropertiesResult RcvTime="2005-12-16T13:23:55.8593750-05:00" 
            ReplyTime="2005-12-16T13:24:00.1093750-05:00" 
            RevisedLocaleID="en-us" ServerState="running" />
        """
        operationName = 'GetProperties'
        msg = self.getInputMessageInstance(operationName)
        msg._ItemIDs
        msg._PropertyNames
        response = self._ports[0].GetProperties(msg)
        result = response._GetPropertiesResult
        
        # not sure these attributes are required but check for them.
        self.failUnless(isinstance(getattr(result, '_attrs', None), dict))
        for k in ['RcvTime','ReplyTime','RevisedLocaleID','ServerState']:
            self.failUnless(result._attrs.has_key(k))
            
        self.failUnless(len(response._PropertyLists) == 0)
        self.failUnless(len(response._Errors) == 0)
        
        
    def test_rpc_Browse(self):
        """FaultException: The item path is not known to the server.
        """
        operationName = 'Browse'
        msg = self.getInputMessageInstance(operationName)
        msg._PropertyNames=['Static']
        msg._attrs = {'ItemPath':'Static'}
        
        self.failUnless(\
            getattr(msg.typecode, 'attribute_typecode_dict', None) is not None,
             )

        self.failUnlessRaises(FaultException, self._ports[0].Browse, msg)
        
        
    def hangs_test_rpc_Read(self):
        """FaultException: The item path is not known to the server.
        """
        msg = self.getInputMessageInstance('Read')
        
        #msg = ReadSoapIn()
        op = msg.new_Options()
        msg.Options = op
        op.set_attribute_ReturnItemTime(True)
        op.set_attribute_ReturnItemName(True)
        op.set_attribute_ClientRequestHandle("")
        op.set_attribute_LocaleID('en-us')

        item_list = msg.new_ItemList()
        msg.ItemList = item_list
        item_list.set_attribute_MaxAge(1000)

        item = item_list.new_Items()
        item_list.Items = item
        item.set_attribute_ItemPath("")
        item.set_attribute_ItemName("Staic.Analog Types.Int")
        item.set_attribute_ClientItemHandle("")
        
        self.failUnless(\
            getattr(msg.typecode, 'attribute_typecode_dict', None) is not None,
             )

        self._ports[0].Read(msg)
        
    def test_nonrpc_anyType(self):
        """serialize an int via anyType, then parse it back.
        """
        from OpcXmlDaSrv_services import ReadSoapOut
        import time
        print ZSI.TC.Any.serialmap
        #tc = ZSI.TC.Any.serialmap.get(int)
        #tc.logger = ZSI.wstools.logging.BasicLogger("AnyInt")
        pyobj = ReadSoapOut()
        pyobj.RItemList = pyobj.new_RItemList()
        item = pyobj.RItemList.Items = pyobj.RItemList.new_Items()
        item.typecode.ofwhat[1].processContents = 'lax'
        item.Value = 123
        s = str(ZSI.SoapWriter().serialize(pyobj))
        print s
        
        ps = ZSI.ParsedSoap(s)
        pyobj = ps.Parse(pyobj.typecode)
        print "Parse\n", pyobj
        for item in pyobj.RItemList.Items:
            print item.Value

        

def makeTestSuite():
    suite = ServiceTestSuite()
    suite.addTest(unittest.makeSuite(OPCServiceTest, "test_", suiteClass=ServiceTestSuite))
    return suite


if __name__ == "__main__" :
    unittest.TestProgram(defaultTest="makeTestSuite")




#!/usr/bin/env python

############################################################################
# Joshua R. Boverhof, LBNL
# See LBNLCopyright for copyright notice!
###########################################################################
import unittest
from ServiceTest import ServiceTestCase, ServiceTestSuite

"""
Unittest for contacting the Amazon Web service.

WSDL:  http://soap.amazon.com/schemas/AmazonWebServices.wsdl

"""

class AmazonServiceTest(ServiceTestCase):
    """Test case for AmazonService Web service.  
    To write a new service just define a method 'test' and retrieve an input message 
    instance via the operation name, fill in the request, and call the RPC method.
    Then you can test the response.

    name -- module name, also used to index service in configuration file.
    test_section -- section test is categorized in, do runtime checking
          to make sure test belongs in this section.

    """
    name = "test_AmazonWebService"
    
    def setUp(self):
        ServiceTestCase.setSection(self,self.name)
        ServiceTestCase.setUp(self)
    
    def testAuthorSearchRequest(self):
        operationName = "AuthorSearchRequest"
        request = self.getInputMessageInstance(operationName)
        #Set up the request
        request._AuthorSearchRequest._author = 'shakespeare'
        request._AuthorSearchRequest._page = '1'
        request._AuthorSearchRequest._mode = 'books'
        request._AuthorSearchRequest._tag = 'webservices-20'
        request._AuthorSearchRequest._type = 'lite'
        request._AuthorSearchRequest._devtag = 'your-dev-tag'
        request._AuthorSearchRequest._format = 'xml'
        request._AuthorSearchRequest._version = '1.0'
        #Test the return message
        response = self.RPC(operationName, request)

def makeTestSuite():
    """makeTestSuite
    """
    suite = ServiceTestSuite()
    suite.addTest(unittest.makeSuite(AmazonServiceTest, 'test'))
    return suite

if __name__ == "__main__" :
    unittest.TestProgram(defaultTest="makeTestSuite")




##################################################
# OpcXmlDaSrv_services_server.py
#      Generated by ZSI.generate.wsdl2dispatch.ServiceModuleWriter
#
##################################################

from OpcXmlDaSrv_services import *
from ZSI.ServiceContainer import ServiceSOAPBinding

class OpcXmlDaSrv(ServiceSOAPBinding):
    soapAction = {}
    root = {}
    _wsdl = """<?xml version=\"1.0\" ?>
<wsdl:definitions targetNamespace=\"http://opcfoundation.org/webservices/XMLDA/1.0/\" xmlns:http=\"http://schemas.xmlsoap.org/wsdl/http/\" xmlns:mime=\"http://schemas.xmlsoap.org/wsdl/mime/\" xmlns:s=\"http://www.w3.org/2001/XMLSchema\" xmlns:soap=\"http://schemas.xmlsoap.org/wsdl/soap/\" xmlns:soapenc=\"http://schemas.xmlsoap.org/soap/encoding/\" xmlns:tm=\"http://microsoft.com/wsdl/mime/textMatching/\" xmlns:tns=\"http://opcfoundation.org/webservices/XMLDA/1.0/\" xmlns:wsdl=\"http://schemas.xmlsoap.org/wsdl/\">
  <wsdl:types>
    <s:schema elementFormDefault=\"qualified\" targetNamespace=\"http://opcfoundation.org/webservices/XMLDA/1.0/\">
      <s:element name=\"GetProperties\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"ItemIDs\" type=\"tns:ItemIdentifier\"/>
            <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"PropertyNames\" type=\"s:QName\"/>
          </s:sequence>
          <s:attribute name=\"LocaleID\" type=\"s:string\"/>
          <s:attribute name=\"ClientRequestHandle\" type=\"s:string\"/>
          <s:attribute name=\"ItemPath\" type=\"s:string\"/>
          <s:attribute default=\"false\" name=\"ReturnAllProperties\" type=\"s:boolean\"/>
          <s:attribute default=\"false\" name=\"ReturnPropertyValues\" type=\"s:boolean\"/>
          <s:attribute default=\"false\" name=\"ReturnErrorText\" type=\"s:boolean\"/>
        </s:complexType>
      </s:element>
      <s:complexType name=\"ItemIdentifier\">
        <s:attribute name=\"ItemPath\" type=\"s:string\"/>
        <s:attribute name=\"ItemName\" type=\"s:string\"/>
      </s:complexType>
      <s:element name=\"GetPropertiesResponse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetPropertiesResult\" type=\"tns:ReplyBase\"/>
            <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"PropertyLists\" type=\"tns:PropertyReplyList\"/>
            <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Errors\" type=\"tns:OPCError\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:complexType name=\"ReplyBase\">
        <s:attribute name=\"RcvTime\" type=\"s:dateTime\" use=\"required\"/>
        <s:attribute name=\"ReplyTime\" type=\"s:dateTime\" use=\"required\"/>
        <s:attribute name=\"ClientRequestHandle\" type=\"s:string\"/>
        <s:attribute name=\"RevisedLocaleID\" type=\"s:string\"/>
        <s:attribute name=\"ServerState\" type=\"tns:serverState\" use=\"required\"/>
      </s:complexType>
      <s:simpleType name=\"serverState\">
        <s:restriction base=\"s:string\">
          <s:enumeration value=\"running\"/>
          <s:enumeration value=\"failed\"/>
          <s:enumeration value=\"noConfig\"/>
          <s:enumeration value=\"suspended\"/>
          <s:enumeration value=\"test\"/>
          <s:enumeration value=\"commFault\"/>
        </s:restriction>
      </s:simpleType>
      <s:complexType name=\"PropertyReplyList\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Properties\" type=\"tns:ItemProperty\"/>
        </s:sequence>
        <s:attribute name=\"ItemPath\" type=\"s:string\"/>
        <s:attribute name=\"ItemName\" type=\"s:string\"/>
        <s:attribute name=\"ResultID\" type=\"s:QName\" use=\"required\"/>
      </s:complexType>
      <s:complexType name=\"ItemProperty\">
        <s:sequence>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Value\"/>
        </s:sequence>
        <s:attribute name=\"Name\" type=\"s:QName\" use=\"required\"/>
        <s:attribute name=\"Description\" type=\"s:string\"/>
        <s:attribute name=\"ItemPath\" type=\"s:string\"/>
        <s:attribute name=\"ItemName\" type=\"s:string\"/>
        <s:attribute name=\"ResultID\" type=\"s:QName\" use=\"required\"/>
      </s:complexType>
      <s:complexType name=\"OPCError\">
        <s:sequence>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Text\" type=\"s:string\"/>
        </s:sequence>
        <s:attribute name=\"ID\" type=\"s:QName\" use=\"required\"/>
      </s:complexType>
      <s:complexType name=\"ArrayOfDouble\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"double\" type=\"s:double\"/>
        </s:sequence>
      </s:complexType>
      <s:complexType name=\"ArrayOfUnsignedShort\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"unsignedShort\" type=\"s:unsignedShort\"/>
        </s:sequence>
      </s:complexType>
      <s:complexType name=\"ArrayOfDateTime\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"dateTime\" type=\"s:dateTime\"/>
        </s:sequence>
      </s:complexType>
      <s:complexType name=\"ArrayOfAnyType\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"anyType\" nillable=\"true\"/>
        </s:sequence>
      </s:complexType>
      <s:complexType name=\"ArrayOfDecimal\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"decimal\" type=\"s:decimal\"/>
        </s:sequence>
      </s:complexType>
      <s:complexType name=\"ArrayOfByte\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"byte\" type=\"s:byte\"/>
        </s:sequence>
      </s:complexType>
      <s:complexType name=\"ArrayOfShort\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"short\" type=\"s:short\"/>
        </s:sequence>
      </s:complexType>
      <s:complexType name=\"ArrayOfBoolean\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"boolean\" type=\"s:boolean\"/>
        </s:sequence>
      </s:complexType>
      <s:complexType name=\"ArrayOfString\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"string\" nillable=\"true\" type=\"s:string\"/>
        </s:sequence>
      </s:complexType>
      <s:complexType name=\"ArrayOfFloat\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"float\" type=\"s:float\"/>
        </s:sequence>
      </s:complexType>
      <s:complexType name=\"ArrayOfInt\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"int\" type=\"s:int\"/>
        </s:sequence>
      </s:complexType>
      <s:complexType name=\"ArrayOfUnsignedInt\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"unsignedInt\" type=\"s:unsignedInt\"/>
        </s:sequence>
      </s:complexType>
      <s:complexType name=\"ArrayOfLong\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"long\" type=\"s:long\"/>
        </s:sequence>
      </s:complexType>
      <s:complexType name=\"ArrayOfUnsignedLong\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"unsignedLong\" type=\"s:unsignedLong\"/>
        </s:sequence>
      </s:complexType>
      <s:element name=\"Subscribe\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:RequestOptions\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ItemList\" type=\"tns:SubscribeRequestItemList\"/>
          </s:sequence>
          <s:attribute name=\"ReturnValuesOnReply\" type=\"s:boolean\" use=\"required\"/>
          <s:attribute default=\"0\" name=\"SubscriptionPingRate\" type=\"s:int\"/>
        </s:complexType>
      </s:element>
      <s:complexType name=\"RequestOptions\">
        <s:attribute default=\"true\" name=\"ReturnErrorText\" type=\"s:boolean\"/>
        <s:attribute default=\"false\" name=\"ReturnDiagnosticInfo\" type=\"s:boolean\"/>
        <s:attribute default=\"false\" name=\"ReturnItemTime\" type=\"s:boolean\"/>
        <s:attribute default=\"false\" name=\"ReturnItemPath\" type=\"s:boolean\"/>
        <s:attribute default=\"false\" name=\"ReturnItemName\" type=\"s:boolean\"/>
        <s:attribute name=\"RequestDeadline\" type=\"s:dateTime\"/>
        <s:attribute name=\"ClientRequestHandle\" type=\"s:string\"/>
        <s:attribute name=\"LocaleID\" type=\"s:string\"/>
      </s:complexType>
      <s:complexType name=\"SubscribeRequestItemList\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Items\" type=\"tns:SubscribeRequestItem\"/>
        </s:sequence>
        <s:attribute name=\"ItemPath\" type=\"s:string\"/>
        <s:attribute name=\"ReqType\" type=\"s:QName\" use=\"required\"/>
        <s:attribute name=\"Deadband\" type=\"s:float\"/>
        <s:attribute name=\"RequestedSamplingRate\" type=\"s:int\"/>
        <s:attribute name=\"EnableBuffering\" type=\"s:boolean\"/>
      </s:complexType>
      <s:complexType name=\"SubscribeRequestItem\">
        <s:attribute name=\"ItemPath\" type=\"s:string\"/>
        <s:attribute name=\"ReqType\" type=\"s:QName\" use=\"required\"/>
        <s:attribute name=\"ItemName\" type=\"s:string\"/>
        <s:attribute name=\"ClientItemHandle\" type=\"s:string\"/>
        <s:attribute name=\"Deadband\" type=\"s:float\"/>
        <s:attribute name=\"RequestedSamplingRate\" type=\"s:int\"/>
        <s:attribute name=\"EnableBuffering\" type=\"s:boolean\"/>
      </s:complexType>
      <s:complexType name=\"SubscribeReplyItemList\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Items\" type=\"tns:SubscribeItemValue\"/>
        </s:sequence>
        <s:attribute name=\"RevisedSamplingRate\" type=\"s:int\"/>
      </s:complexType>
      <s:complexType name=\"SubscribeItemValue\">
        <s:sequence>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ItemValue\" type=\"tns:ItemValue\"/>
        </s:sequence>
        <s:attribute name=\"RevisedSamplingRate\" type=\"s:int\"/>
      </s:complexType>
      <s:complexType name=\"ItemValue\">
        <s:sequence>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DiagnosticInfo\" type=\"s:string\"/>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Value\"/>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Quality\" type=\"tns:OPCQuality\"/>
        </s:sequence>
        <s:attribute name=\"ValueTypeQualifier\" type=\"s:QName\" use=\"required\"/>
        <s:attribute name=\"ItemPath\" type=\"s:string\"/>
        <s:attribute name=\"ItemName\" type=\"s:string\"/>
        <s:attribute name=\"ClientItemHandle\" type=\"s:string\"/>
        <s:attribute name=\"Timestamp\" type=\"s:dateTime\"/>
        <s:attribute name=\"ResultID\" type=\"s:QName\" use=\"required\"/>
      </s:complexType>
      <s:complexType name=\"OPCQuality\">
        <s:attribute default=\"good\" name=\"QualityField\" type=\"tns:qualityBits\"/>
        <s:attribute default=\"none\" name=\"LimitField\" type=\"tns:limitBits\"/>
        <s:attribute default=\"0\" name=\"VendorField\" type=\"s:unsignedByte\"/>
      </s:complexType>
      <s:simpleType name=\"qualityBits\">
        <s:restriction base=\"s:string\">
          <s:enumeration value=\"bad\"/>
          <s:enumeration value=\"badConfigurationError\"/>
          <s:enumeration value=\"badNotConnected\"/>
          <s:enumeration value=\"badDeviceFailure\"/>
          <s:enumeration value=\"badSensorFailure\"/>
          <s:enumeration value=\"badLastKnownValue\"/>
          <s:enumeration value=\"badCommFailure\"/>
          <s:enumeration value=\"badOutOfService\"/>
          <s:enumeration value=\"badWaitingForInitialData\"/>
          <s:enumeration value=\"uncertain\"/>
          <s:enumeration value=\"uncertainLastUsableValue\"/>
          <s:enumeration value=\"uncertainSensorNotAccurate\"/>
          <s:enumeration value=\"uncertainEUExceeded\"/>
          <s:enumeration value=\"uncertainSubNormal\"/>
          <s:enumeration value=\"good\"/>
          <s:enumeration value=\"goodLocalOverride\"/>
        </s:restriction>
      </s:simpleType>
      <s:simpleType name=\"limitBits\">
        <s:restriction base=\"s:string\">
          <s:enumeration value=\"none\"/>
          <s:enumeration value=\"low\"/>
          <s:enumeration value=\"high\"/>
          <s:enumeration value=\"constant\"/>
        </s:restriction>
      </s:simpleType>
      <s:element name=\"SubscribeResponse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SubscribeResult\" type=\"tns:ReplyBase\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"RItemList\" type=\"tns:SubscribeReplyItemList\"/>
            <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Errors\" type=\"tns:OPCError\"/>
          </s:sequence>
          <s:attribute name=\"ServerSubHandle\" type=\"s:string\"/>
        </s:complexType>
      </s:element>
      <s:element name=\"SubscriptionPolledRefresh\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:RequestOptions\"/>
            <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"ServerSubHandles\" type=\"s:string\"/>
          </s:sequence>
          <s:attribute name=\"HoldTime\" type=\"s:dateTime\"/>
          <s:attribute default=\"0\" name=\"WaitTime\" type=\"s:int\"/>
          <s:attribute default=\"false\" name=\"ReturnAllItems\" type=\"s:boolean\"/>
        </s:complexType>
      </s:element>
      <s:complexType name=\"SubscribePolledRefreshReplyItemList\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Items\" type=\"tns:ItemValue\"/>
        </s:sequence>
        <s:attribute name=\"SubscriptionHandle\" type=\"s:string\"/>
      </s:complexType>
      <s:element name=\"SubscriptionPolledRefreshResponse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SubscriptionPolledRefreshResult\" type=\"tns:ReplyBase\"/>
            <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"InvalidServerSubHandles\" type=\"s:string\"/>
            <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"RItemList\" type=\"tns:SubscribePolledRefreshReplyItemList\"/>
            <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Errors\" type=\"tns:OPCError\"/>
          </s:sequence>
          <s:attribute default=\"false\" name=\"DataBufferOverflow\" type=\"s:boolean\"/>
        </s:complexType>
      </s:element>
      <s:element name=\"SubscriptionCancel\">
        <s:complexType>
          <s:attribute name=\"ServerSubHandle\" type=\"s:string\"/>
          <s:attribute name=\"ClientRequestHandle\" type=\"s:string\"/>
        </s:complexType>
      </s:element>
      <s:element name=\"SubscriptionCancelResponse\">
        <s:complexType>
          <s:attribute name=\"ClientRequestHandle\" type=\"s:string\"/>
        </s:complexType>
      </s:element>
      <s:element name=\"GetStatus\">
        <s:complexType>
          <s:attribute name=\"LocaleID\" type=\"s:string\"/>
          <s:attribute name=\"ClientRequestHandle\" type=\"s:string\"/>
        </s:complexType>
      </s:element>
      <s:complexType name=\"ServerStatus\">
        <s:sequence>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"StatusInfo\" type=\"s:string\"/>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"VendorInfo\" type=\"s:string\"/>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"SupportedLocaleIDs\" type=\"s:string\"/>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"SupportedInterfaceVersions\" type=\"tns:interfaceVersion\"/>
        </s:sequence>
        <s:attribute name=\"StartTime\" type=\"s:dateTime\" use=\"required\"/>
        <s:attribute name=\"ProductVersion\" type=\"s:string\"/>
      </s:complexType>
      <s:simpleType name=\"interfaceVersion\">
        <s:restriction base=\"s:string\">
          <s:enumeration value=\"XML_DA_Version_1_0\"/>
          <s:enumeration value=\"DX_Version_1_0\"/>
        </s:restriction>
      </s:simpleType>
      <s:element name=\"GetStatusResponse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetStatusResult\" type=\"tns:ReplyBase\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Status\" type=\"tns:ServerStatus\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"Browse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"PropertyNames\" type=\"s:QName\"/>
          </s:sequence>
          <s:attribute name=\"LocaleID\" type=\"s:string\"/>
          <s:attribute name=\"ClientRequestHandle\" type=\"s:string\"/>
          <s:attribute name=\"ItemPath\" type=\"s:string\"/>
          <s:attribute name=\"ItemName\" type=\"s:string\"/>
          <s:attribute name=\"ContinuationPoint\" type=\"s:string\"/>
          <s:attribute default=\"0\" name=\"MaxElementsReturned\" type=\"s:int\"/>
          <s:attribute default=\"all\" name=\"BrowseFilter\" type=\"tns:browseFilter\"/>
          <s:attribute name=\"ElementNameFilter\" type=\"s:string\"/>
          <s:attribute name=\"VendorFilter\" type=\"s:string\"/>
          <s:attribute default=\"false\" name=\"ReturnAllProperties\" type=\"s:boolean\"/>
          <s:attribute default=\"false\" name=\"ReturnPropertyValues\" type=\"s:boolean\"/>
          <s:attribute default=\"false\" name=\"ReturnErrorText\" type=\"s:boolean\"/>
        </s:complexType>
      </s:element>
      <s:simpleType name=\"browseFilter\">
        <s:restriction base=\"s:string\">
          <s:enumeration value=\"all\"/>
          <s:enumeration value=\"branch\"/>
          <s:enumeration value=\"item\"/>
        </s:restriction>
      </s:simpleType>
      <s:complexType name=\"BrowseElement\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Properties\" type=\"tns:ItemProperty\"/>
        </s:sequence>
        <s:attribute name=\"Name\" type=\"s:string\"/>
        <s:attribute name=\"ItemPath\" type=\"s:string\"/>
        <s:attribute name=\"ItemName\" type=\"s:string\"/>
        <s:attribute name=\"IsItem\" type=\"s:boolean\" use=\"required\"/>
        <s:attribute name=\"HasChildren\" type=\"s:boolean\" use=\"required\"/>
      </s:complexType>
      <s:element name=\"BrowseResponse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"BrowseResult\" type=\"tns:ReplyBase\"/>
            <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Elements\" type=\"tns:BrowseElement\"/>
            <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Errors\" type=\"tns:OPCError\"/>
          </s:sequence>
          <s:attribute name=\"ContinuationPoint\" type=\"s:string\"/>
          <s:attribute default=\"false\" name=\"MoreElements\" type=\"s:boolean\"/>
        </s:complexType>
      </s:element>
      <s:element name=\"Read\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:RequestOptions\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ItemList\" type=\"tns:ReadRequestItemList\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:complexType name=\"ReadRequestItemList\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Items\" type=\"tns:ReadRequestItem\"/>
        </s:sequence>
        <s:attribute name=\"ItemPath\" type=\"s:string\"/>
        <s:attribute name=\"ReqType\" type=\"s:QName\" use=\"required\"/>
        <s:attribute name=\"MaxAge\" type=\"s:int\"/>
      </s:complexType>
      <s:complexType name=\"ReadRequestItem\">
        <s:attribute name=\"ItemPath\" type=\"s:string\"/>
        <s:attribute name=\"ReqType\" type=\"s:QName\" use=\"required\"/>
        <s:attribute name=\"ItemName\" type=\"s:string\"/>
        <s:attribute name=\"ClientItemHandle\" type=\"s:string\"/>
        <s:attribute name=\"MaxAge\" type=\"s:int\"/>
      </s:complexType>
      <s:complexType name=\"ReplyItemList\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Items\" type=\"tns:ItemValue\"/>
        </s:sequence>
        <s:attribute name=\"Reserved\" type=\"s:string\"/>
      </s:complexType>
      <s:element name=\"ReadResponse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ReadResult\" type=\"tns:ReplyBase\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"RItemList\" type=\"tns:ReplyItemList\"/>
            <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Errors\" type=\"tns:OPCError\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"Write\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:RequestOptions\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ItemList\" type=\"tns:WriteRequestItemList\"/>
          </s:sequence>
          <s:attribute name=\"ReturnValuesOnReply\" type=\"s:boolean\" use=\"required\"/>
        </s:complexType>
      </s:element>
      <s:complexType name=\"WriteRequestItemList\">
        <s:sequence>
          <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Items\" type=\"tns:ItemValue\"/>
        </s:sequence>
        <s:attribute name=\"ItemPath\" type=\"s:string\"/>
      </s:complexType>
      <s:element name=\"WriteResponse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"WriteResult\" type=\"tns:ReplyBase\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"RItemList\" type=\"tns:ReplyItemList\"/>
            <s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Errors\" type=\"tns:OPCError\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
    </s:schema>
  </wsdl:types>
  <wsdl:message name=\"GetPropertiesSoapIn\">
    <wsdl:part element=\"tns:GetProperties\" name=\"parameters\"/>
  </wsdl:message>
  <wsdl:message name=\"GetPropertiesSoapOut\">
    <wsdl:part element=\"tns:GetPropertiesResponse\" name=\"parameters\"/>
  </wsdl:message>
  <wsdl:message name=\"SubscribeSoapIn\">
    <wsdl:part element=\"tns:Subscribe\" name=\"parameters\"/>
  </wsdl:message>
  <wsdl:message name=\"SubscribeSoapOut\">
    <wsdl:part element=\"tns:SubscribeResponse\" name=\"parameters\"/>
  </wsdl:message>
  <wsdl:message name=\"SubscriptionPolledRefreshSoapIn\">
    <wsdl:part element=\"tns:SubscriptionPolledRefresh\" name=\"parameters\"/>
  </wsdl:message>
  <wsdl:message name=\"SubscriptionPolledRefreshSoapOut\">
    <wsdl:part element=\"tns:SubscriptionPolledRefreshResponse\" name=\"parameters\"/>
  </wsdl:message>
  <wsdl:message name=\"SubscriptionCancelSoapIn\">
    <wsdl:part element=\"tns:SubscriptionCancel\" name=\"parameters\"/>
  </wsdl:message>
  <wsdl:message name=\"SubscriptionCancelSoapOut\">
    <wsdl:part element=\"tns:SubscriptionCancelResponse\" name=\"parameters\"/>
  </wsdl:message>
  <wsdl:message name=\"GetStatusSoapIn\">
    <wsdl:part element=\"tns:GetStatus\" name=\"parameters\"/>
  </wsdl:message>
  <wsdl:message name=\"GetStatusSoapOut\">
    <wsdl:part element=\"tns:GetStatusResponse\" name=\"parameters\"/>
  </wsdl:message>
  <wsdl:message name=\"BrowseSoapIn\">
    <wsdl:part element=\"tns:Browse\" name=\"parameters\"/>
  </wsdl:message>
  <wsdl:message name=\"BrowseSoapOut\">
    <wsdl:part element=\"tns:BrowseResponse\" name=\"parameters\"/>
  </wsdl:message>
  <wsdl:message name=\"ReadSoapIn\">
    <wsdl:part element=\"tns:Read\" name=\"parameters\"/>
  </wsdl:message>
  <wsdl:message name=\"ReadSoapOut\">
    <wsdl:part element=\"tns:ReadResponse\" name=\"parameters\"/>
  </wsdl:message>
  <wsdl:message name=\"WriteSoapIn\">
    <wsdl:part element=\"tns:Write\" name=\"parameters\"/>
  </wsdl:message>
  <wsdl:message name=\"WriteSoapOut\">
    <wsdl:part element=\"tns:WriteResponse\" name=\"parameters\"/>
  </wsdl:message>
  <wsdl:portType name=\"OpcXmlDaSrvSoap\">
    <wsdl:operation name=\"GetProperties\">
      <wsdl:input message=\"tns:GetPropertiesSoapIn\"/>
      <wsdl:output message=\"tns:GetPropertiesSoapOut\"/>
    </wsdl:operation>
    <wsdl:operation name=\"Subscribe\">
      <wsdl:input message=\"tns:SubscribeSoapIn\"/>
      <wsdl:output message=\"tns:SubscribeSoapOut\"/>
    </wsdl:operation>
    <wsdl:operation name=\"SubscriptionPolledRefresh\">
      <wsdl:input message=\"tns:SubscriptionPolledRefreshSoapIn\"/>
      <wsdl:output message=\"tns:SubscriptionPolledRefreshSoapOut\"/>
    </wsdl:operation>
    <wsdl:operation name=\"SubscriptionCancel\">
      <wsdl:input message=\"tns:SubscriptionCancelSoapIn\"/>
      <wsdl:output message=\"tns:SubscriptionCancelSoapOut\"/>
    </wsdl:operation>
    <wsdl:operation name=\"GetStatus\">
      <wsdl:input message=\"tns:GetStatusSoapIn\"/>
      <wsdl:output message=\"tns:GetStatusSoapOut\"/>
    </wsdl:operation>
    <wsdl:operation name=\"Browse\">
      <wsdl:input message=\"tns:BrowseSoapIn\"/>
      <wsdl:output message=\"tns:BrowseSoapOut\"/>
    </wsdl:operation>
    <wsdl:operation name=\"Read\">
      <wsdl:input message=\"tns:ReadSoapIn\"/>
      <wsdl:output message=\"tns:ReadSoapOut\"/>
    </wsdl:operation>
    <wsdl:operation name=\"Write\">
      <wsdl:input message=\"tns:WriteSoapIn\"/>
      <wsdl:output message=\"tns:WriteSoapOut\"/>
    </wsdl:operation>
  </wsdl:portType>
  <wsdl:binding name=\"OpcXmlDaSrvSoap\" type=\"tns:OpcXmlDaSrvSoap\">
    <soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
    <wsdl:operation name=\"GetProperties\">
      <soap:operation soapAction=\"http://opcfoundation.org/webservices/XMLDA/1.0/GetProperties\" style=\"document\"/>
      <wsdl:input>
        <soap:body use=\"literal\"/>
      </wsdl:input>
      <wsdl:output>
        <soap:body use=\"literal\"/>
      </wsdl:output>
    </wsdl:operation>
    <wsdl:operation name=\"Subscribe\">
      <soap:operation soapAction=\"http://opcfoundation.org/webservices/XMLDA/1.0/Subscribe\" style=\"document\"/>
      <wsdl:input>
        <soap:body use=\"literal\"/>
      </wsdl:input>
      <wsdl:output>
        <soap:body use=\"literal\"/>
      </wsdl:output>
    </wsdl:operation>
    <wsdl:operation name=\"SubscriptionPolledRefresh\">
      <soap:operation soapAction=\"http://opcfoundation.org/webservices/XMLDA/1.0/SubscriptionPolledRefresh\" style=\"document\"/>
      <wsdl:input>
        <soap:body use=\"literal\"/>
      </wsdl:input>
      <wsdl:output>
        <soap:body use=\"literal\"/>
      </wsdl:output>
    </wsdl:operation>
    <wsdl:operation name=\"SubscriptionCancel\">
      <soap:operation soapAction=\"http://opcfoundation.org/webservices/XMLDA/1.0/SubscriptionCancel\" style=\"document\"/>
      <wsdl:input>
        <soap:body use=\"literal\"/>
      </wsdl:input>
      <wsdl:output>
        <soap:body use=\"literal\"/>
      </wsdl:output>
    </wsdl:operation>
    <wsdl:operation name=\"GetStatus\">
      <soap:operation soapAction=\"http://opcfoundation.org/webservices/XMLDA/1.0/GetStatus\" style=\"document\"/>
      <wsdl:input>
        <soap:body use=\"literal\"/>
      </wsdl:input>
      <wsdl:output>
        <soap:body use=\"literal\"/>
      </wsdl:output>
    </wsdl:operation>
    <wsdl:operation name=\"Browse\">
      <soap:operation soapAction=\"http://opcfoundation.org/webservices/XMLDA/1.0/Browse\" style=\"document\"/>
      <wsdl:input>
        <soap:body use=\"literal\"/>
      </wsdl:input>
      <wsdl:output>
        <soap:body use=\"literal\"/>
      </wsdl:output>
    </wsdl:operation>
    <wsdl:operation name=\"Read\">
      <soap:operation soapAction=\"http://opcfoundation.org/webservices/XMLDA/1.0/Read\" style=\"document\"/>
      <wsdl:input>
        <soap:body use=\"literal\"/>
      </wsdl:input>
      <wsdl:output>
        <soap:body use=\"literal\"/>
      </wsdl:output>
    </wsdl:operation>
    <wsdl:operation name=\"Write\">
      <soap:operation soapAction=\"http://opcfoundation.org/webservices/XMLDA/1.0/Write\" style=\"document\"/>
      <wsdl:input>
        <soap:body use=\"literal\"/>
      </wsdl:input>
      <wsdl:output>
        <soap:body use=\"literal\"/>
      </wsdl:output>
    </wsdl:operation>
  </wsdl:binding>
  <wsdl:service name=\"OpcXmlDaSrv\">
    <documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\"/>
    <wsdl:port binding=\"tns:OpcXmlDaSrvSoap\" name=\"OpcXmlDaSrvSoap\">
      <soap:address location=\"http://tswinc.us/XMLDADemo/ts_sim/OpcDaGateway.asmx\"/>
    </wsdl:port>
  </wsdl:service>
</wsdl:definitions>"""

    def __init__(self, post='/XMLDADemo/ts_sim/OpcDaGateway.asmx', **kw):
        ServiceSOAPBinding.__init__(self, post)

    def soap_GetProperties(self, ps):
        self.request = ps.Parse(GetPropertiesSoapIn.typecode)
        return GetPropertiesSoapOut()

    soapAction['http://opcfoundation.org/webservices/XMLDA/1.0/GetProperties'] = 'soap_GetProperties'
    root[(GetPropertiesSoapIn.typecode.nspname,GetPropertiesSoapIn.typecode.pname)] = 'soap_GetProperties'

    def soap_Subscribe(self, ps):
        self.request = ps.Parse(SubscribeSoapIn.typecode)
        return SubscribeSoapOut()

    soapAction['http://opcfoundation.org/webservices/XMLDA/1.0/Subscribe'] = 'soap_Subscribe'
    root[(SubscribeSoapIn.typecode.nspname,SubscribeSoapIn.typecode.pname)] = 'soap_Subscribe'

    def soap_SubscriptionPolledRefresh(self, ps):
        self.request = ps.Parse(SubscriptionPolledRefreshSoapIn.typecode)
        return SubscriptionPolledRefreshSoapOut()

    soapAction['http://opcfoundation.org/webservices/XMLDA/1.0/SubscriptionPolledRefresh'] = 'soap_SubscriptionPolledRefresh'
    root[(SubscriptionPolledRefreshSoapIn.typecode.nspname,SubscriptionPolledRefreshSoapIn.typecode.pname)] = 'soap_SubscriptionPolledRefresh'

    def soap_SubscriptionCancel(self, ps):
        self.request = ps.Parse(SubscriptionCancelSoapIn.typecode)
        return SubscriptionCancelSoapOut()

    soapAction['http://opcfoundation.org/webservices/XMLDA/1.0/SubscriptionCancel'] = 'soap_SubscriptionCancel'
    root[(SubscriptionCancelSoapIn.typecode.nspname,SubscriptionCancelSoapIn.typecode.pname)] = 'soap_SubscriptionCancel'

    def soap_GetStatus(self, ps):
        self.request = ps.Parse(GetStatusSoapIn.typecode)
        return GetStatusSoapOut()

    soapAction['http://opcfoundation.org/webservices/XMLDA/1.0/GetStatus'] = 'soap_GetStatus'
    root[(GetStatusSoapIn.typecode.nspname,GetStatusSoapIn.typecode.pname)] = 'soap_GetStatus'

    def soap_Browse(self, ps):
        self.request = ps.Parse(BrowseSoapIn.typecode)
        return BrowseSoapOut()

    soapAction['http://opcfoundation.org/webservices/XMLDA/1.0/Browse'] = 'soap_Browse'
    root[(BrowseSoapIn.typecode.nspname,BrowseSoapIn.typecode.pname)] = 'soap_Browse'

    def soap_Read(self, ps):
        self.request = ps.Parse(ReadSoapIn.typecode)
        return ReadSoapOut()

    soapAction['http://opcfoundation.org/webservices/XMLDA/1.0/Read'] = 'soap_Read'
    root[(ReadSoapIn.typecode.nspname,ReadSoapIn.typecode.pname)] = 'soap_Read'

    def soap_Write(self, ps):
        self.request = ps.Parse(WriteSoapIn.typecode)
        return WriteSoapOut()

    soapAction['http://opcfoundation.org/webservices/XMLDA/1.0/Write'] = 'soap_Write'
    root[(WriteSoapIn.typecode.nspname,WriteSoapIn.typecode.pname)] = 'soap_Write'




#!/usr/bin/env python

############################################################################
# David W. Robertson, LBNL
# See LBNLCopyright for copyright notice!
###########################################################################

import sys, unittest
import os
import py_compile

#import utils

"""
Tests compilation of wsdl2python generated code.
"""

CONFIG_FILE = 'config.txt'
MODULE_DIR = 'generatedCode'

class CompileCodeTest(unittest.TestCase):
    """Test case for compiling modules resulting from call
       to wsdl2python.WriteServiceModule
    """

    environment = None

    def __init__(self, methodName):
        unittest.TestCase.__init__(self, methodName)

    def setUp(self):
        self.fname = CompileCodeTest.environment.next()
        print self.fname
        sys.stdout.flush()

    def __str__(self):
        teststr = unittest.TestCase.__str__(self)
        if hasattr(self, "fname"):
            return "%s: %s" % (teststr, self.fname)
        else:
            return "%s" % (teststr)

    def test_compile(self):
        if not self.fname:
            return
        try:
            py_compile.compile(self.fname, doraise=True)

            # py_compile.compile raises bogus indentation exceptions
        except py_compile.PyCompileError, err:
            if err.msg.find('IndentationError') != -1:
                pass
            else:
                raise

def getFiles():
    cmd = "ls %s*.py" % (MODULE_DIR + os.sep)
    result = os.popen(cmd)
    fnameList = []
    for fname in result.readlines():
         fnameList.append(fname[:-1])
    return fnameList

def makeTestSuite():
    suite = unittest.TestSuite()
    fnameList = getFiles()
    CompileCodeTest.environment = iter(fnameList)
    listLen = len(fnameList)
    for i in range(0, listLen):
        suite.addTest(unittest.makeSuite(CompileCodeTest, 'test_'))
    return suite


def main():
    unittest.TestProgram(defaultTest="makeTestSuite")
                  
if __name__ == "__main__" :
    main()



#!/bin/env python
############################################################################
# Joshua Boverhof<JRBoverhof@lbl.gov>, LBNL
# Monte Goode <MMGoode@lbl.gov>, LBNL
# See Copyright for copyright notice!
###########################################################################
import sys, optparse, os
from ZSI.wstools import WSDLTools
from ZSI.generate.wsdl2python import WriteServiceModule
from ZSI.generate.wsdl2dispatch import ServiceModuleWriter as ServiceDescription
from ZSI.generate.wsdl2dispatch import DelAuthServiceModuleWriter as DelAuthServiceDescription
from ZSI.generate.wsdl2dispatch import WSAServiceModuleWriter as ServiceDescriptionWSA
from ZSI.generate.wsdl2dispatch import DelAuthWSAServiceModuleWriter as DelAuthServiceDescriptionWSA
from ZSI.wstools.logging import setBasicLoggerDEBUG
from ZSI.generate.utility import TextProtect
from ZSI.generate import utility

"""
wsdl2dispatch

A utility for automatically generating service skeleton code from a wsdl
definition.
"""

def SetDebugCallback(option, opt, value, parser, *args, **kwargs):
    setBasicLoggerDEBUG()

def main():
    op = optparse.OptionParser()
    op.add_option("-f", "--file",
                  action="store", dest="file", default=None, type="string",
                  help="file to load wsdl from")
    op.add_option("-u", "--url",
                  action="store", dest="url", default=None, type="string",
                  help="URL to load wsdl from")
    op.add_option("-a", "--address",
                  action="store_true", dest="address", default=False,
                  help="ws-addressing support, must include WS-Addressing schema.")
    op.add_option("-e", "--extended",
                  action="store_true", dest="extended", default=False,
                  help="Extended code generation.")
    op.add_option("-d", "--debug",
                  action="callback", callback=SetDebugCallback,
                  help="debug output")
    op.add_option("-t", "--types",
                  action="store", dest="types", default=None, type="string",
                  help="file to load types from")
    op.add_option("-o", "--output-dir",
                  action="store", dest="output_directory", default=".", type="string",
                  help="file to load types from")
    op.add_option("-s", "--simple-naming",
                  action="store_true", dest="simple_naming", default=False,
                  help="Simplify generated naming.")
    (options, args) = op.parse_args()

    if options.simple_naming:
        ServiceDescription.server_module_suffix = '_interface'
        ServiceDescription.func_aname = lambda instnc,n: TextProtect(n)
        ServiceDescription.separate_messages = True
        # use module names rather than their number.
        utility.namespace_name = lambda cls, ns: utility.Namespace2ModuleName(ns)

    reader = WSDLTools.WSDLReader()
    wsdl = None
    if options.file is not None:
        wsdl = reader.loadFromFile(options.file)
    elif options.url is not None:
        wsdl = reader.loadFromURL(options.url)

    assert wsdl is not None, 'Must specify WSDL either with --file or --url'

    ss = None
    if options.address is True:
        if options.extended:
            ss = DelAuthServiceDescriptionWSA(do_extended=options.extended)
        else:
            ss = ServiceDescriptionWSA(do_extended=options.extended)
    else:
        if options.extended:
            ss = DelAuthServiceDescription(do_extended=options.extended)
        else:
            ss = ServiceDescription(do_extended=options.extended)

    ss.fromWSDL(wsdl)
    fd = open( os.path.join(options.output_directory, ss.getServiceModuleName()+'.py'), 'w+')
    ss.write(fd)
    fd.close()

if __name__ == '__main__':
    main()



##################################################
# ZipCodeResolver_services_server.py
#      Generated by ZSI.generate.wsdl2dispatch.ServiceModuleWriter
#
##################################################

from ZipCodeResolver_services import *
from ZSI.ServiceContainer import ServiceSOAPBinding

class ZipCodeResolver(ServiceSOAPBinding):
    soapAction = {}
    root = {}
    _wsdl = """<?xml version=\"1.0\" ?>
<definitions targetNamespace=\"http://webservices.eraserver.net/\" xmlns=\"http://schemas.xmlsoap.org/wsdl/\" xmlns:http=\"http://schemas.xmlsoap.org/wsdl/http/\" xmlns:mime=\"http://schemas.xmlsoap.org/wsdl/mime/\" xmlns:s=\"http://www.w3.org/2001/XMLSchema\" xmlns:s0=\"http://webservices.eraserver.net/\" xmlns:soap=\"http://schemas.xmlsoap.org/wsdl/soap/\" xmlns:soapenc=\"http://schemas.xmlsoap.org/soap/encoding/\" xmlns:tm=\"http://microsoft.com/wsdl/mime/textMatching/\">
  <types>
    <s:schema elementFormDefault=\"qualified\" targetNamespace=\"http://webservices.eraserver.net/\">
      <s:element name=\"FullZipCode\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"accessCode\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"address\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"city\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"state\" type=\"s:string\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"FullZipCodeResponse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FullZipCodeResult\" type=\"s:string\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"ShortZipCode\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"accessCode\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"address\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"city\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"state\" type=\"s:string\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"ShortZipCodeResponse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ShortZipCodeResult\" type=\"s:string\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"CorrectedAddressHtml\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"accessCode\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"address\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"city\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"state\" type=\"s:string\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"CorrectedAddressHtmlResponse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CorrectedAddressHtmlResult\" type=\"s:string\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"CorrectedAddressXml\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"accessCode\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"address\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"city\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"state\" type=\"s:string\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"CorrectedAddressXmlResponse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"CorrectedAddressXmlResult\" type=\"s0:USPSAddress\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:complexType name=\"USPSAddress\">
        <s:sequence>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Street\" type=\"s:string\"/>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"City\" type=\"s:string\"/>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"State\" type=\"s:string\"/>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ShortZIP\" type=\"s:string\"/>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FullZIP\" type=\"s:string\"/>
        </s:sequence>
      </s:complexType>
      <s:element name=\"VersionInfo\">
        <s:complexType/>
      </s:element>
      <s:element name=\"VersionInfoResponse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"VersionInfoResult\" type=\"s:string\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"string\" nillable=\"true\" type=\"s:string\"/>
      <s:element name=\"USPSAddress\" type=\"s0:USPSAddress\"/>
    </s:schema>
  </types>
  <message name=\"FullZipCodeSoapIn\">
    <part element=\"s0:FullZipCode\" name=\"parameters\"/>
  </message>
  <message name=\"FullZipCodeSoapOut\">
    <part element=\"s0:FullZipCodeResponse\" name=\"parameters\"/>
  </message>
  <message name=\"ShortZipCodeSoapIn\">
    <part element=\"s0:ShortZipCode\" name=\"parameters\"/>
  </message>
  <message name=\"ShortZipCodeSoapOut\">
    <part element=\"s0:ShortZipCodeResponse\" name=\"parameters\"/>
  </message>
  <message name=\"CorrectedAddressHtmlSoapIn\">
    <part element=\"s0:CorrectedAddressHtml\" name=\"parameters\"/>
  </message>
  <message name=\"CorrectedAddressHtmlSoapOut\">
    <part element=\"s0:CorrectedAddressHtmlResponse\" name=\"parameters\"/>
  </message>
  <message name=\"CorrectedAddressXmlSoapIn\">
    <part element=\"s0:CorrectedAddressXml\" name=\"parameters\"/>
  </message>
  <message name=\"CorrectedAddressXmlSoapOut\">
    <part element=\"s0:CorrectedAddressXmlResponse\" name=\"parameters\"/>
  </message>
  <message name=\"VersionInfoSoapIn\">
    <part element=\"s0:VersionInfo\" name=\"parameters\"/>
  </message>
  <message name=\"VersionInfoSoapOut\">
    <part element=\"s0:VersionInfoResponse\" name=\"parameters\"/>
  </message>
  <message name=\"FullZipCodeHttpGetIn\">
    <part name=\"accessCode\" type=\"s:string\"/>
    <part name=\"address\" type=\"s:string\"/>
    <part name=\"city\" type=\"s:string\"/>
    <part name=\"state\" type=\"s:string\"/>
  </message>
  <message name=\"FullZipCodeHttpGetOut\">
    <part element=\"s0:string\" name=\"Body\"/>
  </message>
  <message name=\"ShortZipCodeHttpGetIn\">
    <part name=\"accessCode\" type=\"s:string\"/>
    <part name=\"address\" type=\"s:string\"/>
    <part name=\"city\" type=\"s:string\"/>
    <part name=\"state\" type=\"s:string\"/>
  </message>
  <message name=\"ShortZipCodeHttpGetOut\">
    <part element=\"s0:string\" name=\"Body\"/>
  </message>
  <message name=\"CorrectedAddressHtmlHttpGetIn\">
    <part name=\"accessCode\" type=\"s:string\"/>
    <part name=\"address\" type=\"s:string\"/>
    <part name=\"city\" type=\"s:string\"/>
    <part name=\"state\" type=\"s:string\"/>
  </message>
  <message name=\"CorrectedAddressHtmlHttpGetOut\">
    <part element=\"s0:string\" name=\"Body\"/>
  </message>
  <message name=\"CorrectedAddressXmlHttpGetIn\">
    <part name=\"accessCode\" type=\"s:string\"/>
    <part name=\"address\" type=\"s:string\"/>
    <part name=\"city\" type=\"s:string\"/>
    <part name=\"state\" type=\"s:string\"/>
  </message>
  <message name=\"CorrectedAddressXmlHttpGetOut\">
    <part element=\"s0:USPSAddress\" name=\"Body\"/>
  </message>
  <message name=\"VersionInfoHttpGetIn\"/>
  <message name=\"VersionInfoHttpGetOut\">
    <part element=\"s0:string\" name=\"Body\"/>
  </message>
  <message name=\"FullZipCodeHttpPostIn\">
    <part name=\"accessCode\" type=\"s:string\"/>
    <part name=\"address\" type=\"s:string\"/>
    <part name=\"city\" type=\"s:string\"/>
    <part name=\"state\" type=\"s:string\"/>
  </message>
  <message name=\"FullZipCodeHttpPostOut\">
    <part element=\"s0:string\" name=\"Body\"/>
  </message>
  <message name=\"ShortZipCodeHttpPostIn\">
    <part name=\"accessCode\" type=\"s:string\"/>
    <part name=\"address\" type=\"s:string\"/>
    <part name=\"city\" type=\"s:string\"/>
    <part name=\"state\" type=\"s:string\"/>
  </message>
  <message name=\"ShortZipCodeHttpPostOut\">
    <part element=\"s0:string\" name=\"Body\"/>
  </message>
  <message name=\"CorrectedAddressHtmlHttpPostIn\">
    <part name=\"accessCode\" type=\"s:string\"/>
    <part name=\"address\" type=\"s:string\"/>
    <part name=\"city\" type=\"s:string\"/>
    <part name=\"state\" type=\"s:string\"/>
  </message>
  <message name=\"CorrectedAddressHtmlHttpPostOut\">
    <part element=\"s0:string\" name=\"Body\"/>
  </message>
  <message name=\"CorrectedAddressXmlHttpPostIn\">
    <part name=\"accessCode\" type=\"s:string\"/>
    <part name=\"address\" type=\"s:string\"/>
    <part name=\"city\" type=\"s:string\"/>
    <part name=\"state\" type=\"s:string\"/>
  </message>
  <message name=\"CorrectedAddressXmlHttpPostOut\">
    <part element=\"s0:USPSAddress\" name=\"Body\"/>
  </message>
  <message name=\"VersionInfoHttpPostIn\"/>
  <message name=\"VersionInfoHttpPostOut\">
    <part element=\"s0:string\" name=\"Body\"/>
  </message>
  <portType name=\"ZipCodeResolverSoap\">
    <operation name=\"FullZipCode\">
      <documentation>Given a valid accesscode, street address, city, and state, returns the ZIP code in NNNNN-NNNN format. If an error occurs, returns 00000-0000 instead. Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:FullZipCodeSoapIn\"/>
      <output message=\"s0:FullZipCodeSoapOut\"/>
    </operation>
    <operation name=\"ShortZipCode\">
      <documentation>Given a valid street address, city, and state, returns the ZIP code in NNNNN format. If an error occurs, returns 00000 instead. Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:ShortZipCodeSoapIn\"/>
      <output message=\"s0:ShortZipCodeSoapOut\"/>
    </operation>
    <operation name=\"CorrectedAddressHtml\">
      <documentation>Given a valid street address, city, and state, returns an HTML version of the USPS corrected address including the ZIP Code in NNNNN-NNNN format. If an error occurs, returns 'ERROR - unable to return corrected address'.  Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:CorrectedAddressHtmlSoapIn\"/>
      <output message=\"s0:CorrectedAddressHtmlSoapOut\"/>
    </operation>
    <operation name=\"CorrectedAddressXml\">
      <documentation>Given a valid street address, city, and state, returns an USPSADDRESS structure with STREET, CITY, STATE, and SHORTZIP and FULLZIP elements. If an error occurs all elements in the structure are empty.  Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:CorrectedAddressXmlSoapIn\"/>
      <output message=\"s0:CorrectedAddressXmlSoapOut\"/>
    </operation>
    <operation name=\"VersionInfo\">
      <documentation>Returns the web service name, current version, date and copyright information.</documentation>
      <input message=\"s0:VersionInfoSoapIn\"/>
      <output message=\"s0:VersionInfoSoapOut\"/>
    </operation>
  </portType>
  <portType name=\"ZipCodeResolverHttpGet\">
    <operation name=\"FullZipCode\">
      <documentation>Given a valid accesscode, street address, city, and state, returns the ZIP code in NNNNN-NNNN format. If an error occurs, returns 00000-0000 instead. Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:FullZipCodeHttpGetIn\"/>
      <output message=\"s0:FullZipCodeHttpGetOut\"/>
    </operation>
    <operation name=\"ShortZipCode\">
      <documentation>Given a valid street address, city, and state, returns the ZIP code in NNNNN format. If an error occurs, returns 00000 instead. Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:ShortZipCodeHttpGetIn\"/>
      <output message=\"s0:ShortZipCodeHttpGetOut\"/>
    </operation>
    <operation name=\"CorrectedAddressHtml\">
      <documentation>Given a valid street address, city, and state, returns an HTML version of the USPS corrected address including the ZIP Code in NNNNN-NNNN format. If an error occurs, returns 'ERROR - unable to return corrected address'.  Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:CorrectedAddressHtmlHttpGetIn\"/>
      <output message=\"s0:CorrectedAddressHtmlHttpGetOut\"/>
    </operation>
    <operation name=\"CorrectedAddressXml\">
      <documentation>Given a valid street address, city, and state, returns an USPSADDRESS structure with STREET, CITY, STATE, and SHORTZIP and FULLZIP elements. If an error occurs all elements in the structure are empty.  Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:CorrectedAddressXmlHttpGetIn\"/>
      <output message=\"s0:CorrectedAddressXmlHttpGetOut\"/>
    </operation>
    <operation name=\"VersionInfo\">
      <documentation>Returns the web service name, current version, date and copyright information.</documentation>
      <input message=\"s0:VersionInfoHttpGetIn\"/>
      <output message=\"s0:VersionInfoHttpGetOut\"/>
    </operation>
  </portType>
  <portType name=\"ZipCodeResolverHttpPost\">
    <operation name=\"FullZipCode\">
      <documentation>Given a valid accesscode, street address, city, and state, returns the ZIP code in NNNNN-NNNN format. If an error occurs, returns 00000-0000 instead. Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:FullZipCodeHttpPostIn\"/>
      <output message=\"s0:FullZipCodeHttpPostOut\"/>
    </operation>
    <operation name=\"ShortZipCode\">
      <documentation>Given a valid street address, city, and state, returns the ZIP code in NNNNN format. If an error occurs, returns 00000 instead. Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:ShortZipCodeHttpPostIn\"/>
      <output message=\"s0:ShortZipCodeHttpPostOut\"/>
    </operation>
    <operation name=\"CorrectedAddressHtml\">
      <documentation>Given a valid street address, city, and state, returns an HTML version of the USPS corrected address including the ZIP Code in NNNNN-NNNN format. If an error occurs, returns 'ERROR - unable to return corrected address'.  Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:CorrectedAddressHtmlHttpPostIn\"/>
      <output message=\"s0:CorrectedAddressHtmlHttpPostOut\"/>
    </operation>
    <operation name=\"CorrectedAddressXml\">
      <documentation>Given a valid street address, city, and state, returns an USPSADDRESS structure with STREET, CITY, STATE, and SHORTZIP and FULLZIP elements. If an error occurs all elements in the structure are empty.  Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:CorrectedAddressXmlHttpPostIn\"/>
      <output message=\"s0:CorrectedAddressXmlHttpPostOut\"/>
    </operation>
    <operation name=\"VersionInfo\">
      <documentation>Returns the web service name, current version, date and copyright information.</documentation>
      <input message=\"s0:VersionInfoHttpPostIn\"/>
      <output message=\"s0:VersionInfoHttpPostOut\"/>
    </operation>
  </portType>
  <binding name=\"ZipCodeResolverSoap\" type=\"s0:ZipCodeResolverSoap\">
    <soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
    <operation name=\"FullZipCode\">
      <soap:operation soapAction=\"http://webservices.eraserver.net/FullZipCode\" style=\"document\"/>
      <input>
        <soap:body use=\"literal\"/>
      </input>
      <output>
        <soap:body use=\"literal\"/>
      </output>
    </operation>
    <operation name=\"ShortZipCode\">
      <soap:operation soapAction=\"http://webservices.eraserver.net/ShortZipCode\" style=\"document\"/>
      <input>
        <soap:body use=\"literal\"/>
      </input>
      <output>
        <soap:body use=\"literal\"/>
      </output>
    </operation>
    <operation name=\"CorrectedAddressHtml\">
      <soap:operation soapAction=\"http://webservices.eraserver.net/CorrectedAddressHtml\" style=\"document\"/>
      <input>
        <soap:body use=\"literal\"/>
      </input>
      <output>
        <soap:body use=\"literal\"/>
      </output>
    </operation>
    <operation name=\"CorrectedAddressXml\">
      <soap:operation soapAction=\"http://webservices.eraserver.net/CorrectedAddressXml\" style=\"document\"/>
      <input>
        <soap:body use=\"literal\"/>
      </input>
      <output>
        <soap:body use=\"literal\"/>
      </output>
    </operation>
    <operation name=\"VersionInfo\">
      <soap:operation soapAction=\"http://webservices.eraserver.net/VersionInfo\" style=\"document\"/>
      <input>
        <soap:body use=\"literal\"/>
      </input>
      <output>
        <soap:body use=\"literal\"/>
      </output>
    </operation>
  </binding>
  <binding name=\"ZipCodeResolverHttpGet\" type=\"s0:ZipCodeResolverHttpGet\">
    <http:binding verb=\"GET\"/>
    <operation name=\"FullZipCode\">
      <http:operation location=\"/FullZipCode\"/>
      <input>
        <http:urlEncoded/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
    <operation name=\"ShortZipCode\">
      <http:operation location=\"/ShortZipCode\"/>
      <input>
        <http:urlEncoded/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
    <operation name=\"CorrectedAddressHtml\">
      <http:operation location=\"/CorrectedAddressHtml\"/>
      <input>
        <http:urlEncoded/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
    <operation name=\"CorrectedAddressXml\">
      <http:operation location=\"/CorrectedAddressXml\"/>
      <input>
        <http:urlEncoded/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
    <operation name=\"VersionInfo\">
      <http:operation location=\"/VersionInfo\"/>
      <input>
        <http:urlEncoded/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
  </binding>
  <binding name=\"ZipCodeResolverHttpPost\" type=\"s0:ZipCodeResolverHttpPost\">
    <http:binding verb=\"POST\"/>
    <operation name=\"FullZipCode\">
      <http:operation location=\"/FullZipCode\"/>
      <input>
        <mime:content type=\"application/x-www-form-urlencoded\"/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
    <operation name=\"ShortZipCode\">
      <http:operation location=\"/ShortZipCode\"/>
      <input>
        <mime:content type=\"application/x-www-form-urlencoded\"/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
    <operation name=\"CorrectedAddressHtml\">
      <http:operation location=\"/CorrectedAddressHtml\"/>
      <input>
        <mime:content type=\"application/x-www-form-urlencoded\"/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
    <operation name=\"CorrectedAddressXml\">
      <http:operation location=\"/CorrectedAddressXml\"/>
      <input>
        <mime:content type=\"application/x-www-form-urlencoded\"/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
    <operation name=\"VersionInfo\">
      <http:operation location=\"/VersionInfo\"/>
      <input>
        <mime:content type=\"application/x-www-form-urlencoded\"/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
  </binding>
  <service name=\"ZipCodeResolver\">
    <documentation>Given a valid street address, city, and state, this service returns the proper ZIP code, ZIP code+4, or USPS corrected address. NOTE: This service is meant for non-commercial, personal use only.</documentation>
    <port binding=\"s0:ZipCodeResolverSoap\" name=\"ZipCodeResolverSoap\">
      <soap:address location=\"http://webservices.eraserver.net/zipcoderesolver/zipcoderesolver.asmx\"/>
    </port>
    <port binding=\"s0:ZipCodeResolverHttpGet\" name=\"ZipCodeResolverHttpGet\">
      <http:address location=\"http://webservices.eraserver.net/zipcoderesolver/zipcoderesolver.asmx\"/>
    </port>
    <port binding=\"s0:ZipCodeResolverHttpPost\" name=\"ZipCodeResolverHttpPost\">
      <http:address location=\"http://webservices.eraserver.net/zipcoderesolver/zipcoderesolver.asmx\"/>
    </port>
  </service>
</definitions>"""

    def __init__(self, post='/zipcoderesolver/zipcoderesolver.asmx', **kw):
        ServiceSOAPBinding.__init__(self, post)

    def soap_FullZipCode(self, ps):
        self.request = ps.Parse(FullZipCodeSoapIn.typecode)
        return FullZipCodeSoapOut()

    soapAction['http://webservices.eraserver.net/FullZipCode'] = 'soap_FullZipCode'
    root[(FullZipCodeSoapIn.typecode.nspname,FullZipCodeSoapIn.typecode.pname)] = 'soap_FullZipCode'

    def soap_ShortZipCode(self, ps):
        self.request = ps.Parse(ShortZipCodeSoapIn.typecode)
        return ShortZipCodeSoapOut()

    soapAction['http://webservices.eraserver.net/ShortZipCode'] = 'soap_ShortZipCode'
    root[(ShortZipCodeSoapIn.typecode.nspname,ShortZipCodeSoapIn.typecode.pname)] = 'soap_ShortZipCode'

    def soap_CorrectedAddressHtml(self, ps):
        self.request = ps.Parse(CorrectedAddressHtmlSoapIn.typecode)
        return CorrectedAddressHtmlSoapOut()

    soapAction['http://webservices.eraserver.net/CorrectedAddressHtml'] = 'soap_CorrectedAddressHtml'
    root[(CorrectedAddressHtmlSoapIn.typecode.nspname,CorrectedAddressHtmlSoapIn.typecode.pname)] = 'soap_CorrectedAddressHtml'

    def soap_CorrectedAddressXml(self, ps):
        self.request = ps.Parse(CorrectedAddressXmlSoapIn.typecode)
        return CorrectedAddressXmlSoapOut()

    soapAction['http://webservices.eraserver.net/CorrectedAddressXml'] = 'soap_CorrectedAddressXml'
    root[(CorrectedAddressXmlSoapIn.typecode.nspname,CorrectedAddressXmlSoapIn.typecode.pname)] = 'soap_CorrectedAddressXml'

    def soap_VersionInfo(self, ps):
        self.request = ps.Parse(VersionInfoSoapIn.typecode)
        return VersionInfoSoapOut()

    soapAction['http://webservices.eraserver.net/VersionInfo'] = 'soap_VersionInfo'
    root[(VersionInfoSoapIn.typecode.nspname,VersionInfoSoapIn.typecode.pname)] = 'soap_VersionInfo'

    def soap_FullZipCode(self, ps):
        self.request = ps.Parse(FullZipCodeHttpGetIn.typecode)
        return FullZipCodeHttpGetOut()

    soapAction[''] = 'soap_FullZipCode'
    root[(FullZipCodeHttpGetIn.typecode.nspname,FullZipCodeHttpGetIn.typecode.pname)] = 'soap_FullZipCode'

    def soap_ShortZipCode(self, ps):
        self.request = ps.Parse(ShortZipCodeHttpGetIn.typecode)
        return ShortZipCodeHttpGetOut()

    soapAction[''] = 'soap_ShortZipCode'
    root[(ShortZipCodeHttpGetIn.typecode.nspname,ShortZipCodeHttpGetIn.typecode.pname)] = 'soap_ShortZipCode'

    def soap_CorrectedAddressHtml(self, ps):
        self.request = ps.Parse(CorrectedAddressHtmlHttpGetIn.typecode)
        return CorrectedAddressHtmlHttpGetOut()

    soapAction[''] = 'soap_CorrectedAddressHtml'
    root[(CorrectedAddressHtmlHttpGetIn.typecode.nspname,CorrectedAddressHtmlHttpGetIn.typecode.pname)] = 'soap_CorrectedAddressHtml'

    def soap_CorrectedAddressXml(self, ps):
        self.request = ps.Parse(CorrectedAddressXmlHttpGetIn.typecode)
        return CorrectedAddressXmlHttpGetOut()

    soapAction[''] = 'soap_CorrectedAddressXml'
    root[(CorrectedAddressXmlHttpGetIn.typecode.nspname,CorrectedAddressXmlHttpGetIn.typecode.pname)] = 'soap_CorrectedAddressXml'

    def soap_VersionInfo(self, ps):
        self.request = ps.Parse(VersionInfoHttpGetIn.typecode)
        return VersionInfoHttpGetOut()

    soapAction[''] = 'soap_VersionInfo'
    root[(VersionInfoHttpGetIn.typecode.nspname,VersionInfoHttpGetIn.typecode.pname)] = 'soap_VersionInfo'

    def soap_FullZipCode(self, ps):
        self.request = ps.Parse(FullZipCodeHttpPostIn.typecode)
        return FullZipCodeHttpPostOut()

    soapAction[''] = 'soap_FullZipCode'
    root[(FullZipCodeHttpPostIn.typecode.nspname,FullZipCodeHttpPostIn.typecode.pname)] = 'soap_FullZipCode'

    def soap_ShortZipCode(self, ps):
        self.request = ps.Parse(ShortZipCodeHttpPostIn.typecode)
        return ShortZipCodeHttpPostOut()

    soapAction[''] = 'soap_ShortZipCode'
    root[(ShortZipCodeHttpPostIn.typecode.nspname,ShortZipCodeHttpPostIn.typecode.pname)] = 'soap_ShortZipCode'

    def soap_CorrectedAddressHtml(self, ps):
        self.request = ps.Parse(CorrectedAddressHtmlHttpPostIn.typecode)
        return CorrectedAddressHtmlHttpPostOut()

    soapAction[''] = 'soap_CorrectedAddressHtml'
    root[(CorrectedAddressHtmlHttpPostIn.typecode.nspname,CorrectedAddressHtmlHttpPostIn.typecode.pname)] = 'soap_CorrectedAddressHtml'

    def soap_CorrectedAddressXml(self, ps):
        self.request = ps.Parse(CorrectedAddressXmlHttpPostIn.typecode)
        return CorrectedAddressXmlHttpPostOut()

    soapAction[''] = 'soap_CorrectedAddressXml'
    root[(CorrectedAddressXmlHttpPostIn.typecode.nspname,CorrectedAddressXmlHttpPostIn.typecode.pname)] = 'soap_CorrectedAddressXml'

    def soap_VersionInfo(self, ps):
        self.request = ps.Parse(VersionInfoHttpPostIn.typecode)
        return VersionInfoHttpPostOut()

    soapAction[''] = 'soap_VersionInfo'
    root[(VersionInfoHttpPostIn.typecode.nspname,VersionInfoHttpPostIn.typecode.pname)] = 'soap_VersionInfo'




#!/usr/bin/env python

############################################################################
# David W. Robertson, LBNL
# See LBNLCopyright for copyright notice!
###########################################################################
import sys, unittest
from ServiceTest import ServiceTestCase, ServiceTestSuite
"""
Unittest for contacting the StationInfo portType of the GlobalWeather
Web service.

WSDL:  http://live.capescience.com/wsdl/GlobalWeather.wsdl
"""

CONFIG_FILE = 'config.txt'
CONFIG_SECTION = 'complex_types'
SERVICE_NAME = 'GlobalWeather'
PORT_NAME = 'StationInfo'


class StationInfoTest(ServiceTestCase):
    """Test case for GlobalWeather Web service, port type StationInfo
    """
    
    name = "test_GlobalWeather_si"

    def setUp(self):
        self._portName = "StationInfo"
        ServiceTestCase.setSection(self,self.name)
        ServiceTestCase.setUp(self)

    def test_getStation(self):
        operationName = "getStation"
        request = self.getInputMessageInstance(operationName)    
        request._code = 'SFO'
        self.RPC(operationName, request)
    
    def test_isValidCode(self):
        operationName = "isValidCode"
        request = self.getInputMessageInstance(operationName)
        request._code = 'SFO'
        self.RPC(operationName, request)
    
    def test_listCountries(self):
        operationName = "listCountries"
        request = self.getInputMessageInstance(operationName)
        self.RPC(operationName, request)
        
    def test_searchByCode(self):
        operationName = 'searchByCode'
        request = self.getInputMessageInstance(operationName)
        request._code = 'SFO'
        self.RPC(operationName, request)
    
    def test_searchByCountry(self):
        operationName = 'searchByCountry'
        request = self.getInputMessageInstance(operationName)
        request._country = 'Australia'
        self.RPC(operationName, request)
    
        # can't find what valid name is, returns empty result
    def test_searchByName(self):
        operationName = 'searchByName'
        request = self.getInputMessageInstance(operationName)
        request._name = 'San Francisco Airport'
        self.RPC(operationName, request)
    
        # can't find what valid region is, returns empty result
    def test_searchByRegion(self):
        operationName = 'searchByRegion'
        request = self.getInputMessageInstance(operationName)
        request._region = 'Europe'
        self.RPC(operationName, request)


def makeTestSuite():
    suite = ServiceTestSuite()
    suite.addTest(unittest.makeSuite(StationInfoTest, 'test_'))
    return suite


if __name__ == "__main__" :
    unittest.TestProgram(defaultTest="makeTestSuite")
